% Auto-generated chapter 41 for abudawud
% Hadiths in this chapter: 102

\hadithdefcmd{abudawud}{4494}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ قُرَيْظَةُ وَالنَّضِيرُ - وَكَانَ النَّضِيرُ أَشْرَفَ مِنْ قُرَيْظَةَ - فَكَانَ إِذَا قَتَلَ رَجُلٌ مِنْ قُرَيْظَةَ رَجُلاً مِنَ النَّضِيرِ قُتِلَ بِهِ وَإِذَا قَتَلَ رَجُلٌ مِنَ النَّضِيرِ رَجُلاً مِنْ قُرَيْظَةَ فُودِيَ بِمِائَةِ وَسْقٍ مِنْ تَمْرٍ فَلَمَّا بُعِثَ النَّبِيُّ صلى الله عليه وسلم قَتَلَ رَجُلٌ مِنَ النَّضِيرِ رَجُلاً مِنْ قُرَيْظَةَ فَقَالُوا ادْفَعُوهُ إِلَيْنَا نَقْتُلْهُ ‏.‏ فَقَالُوا بَيْنَنَا وَبَيْنَكُمُ النَّبِيُّ صلى الله عليه وسلم فَأَتَوْهُ فَنَزَلَتْ ‏\{‏ وَإِنْ حَكَمْتَ فَاحْكُمْ بَيْنَهُمْ بِالْقِسْطِ ‏\}‏ وَالْقِسْطُ النَّفْسُ بِالنَّفْسِ ثُمَّ نَزَلَتْ ‏\{‏ أَفَحُكْمَ الْجَاهِلِيَّةِ يَبْغُونَ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ قُرَيْظَةُ وَالنَّضِيرُ جَمِيعًا مِنْ وَلَدِ هَارُونَ النَّبِيِّ عَلَيْهِ السَّلاَمُ ‏.‏\hadithno{4494}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Abdullah Ibn Abbas: Qurayzah and Nadir (were two Jewish tribes). An-Nadir were nobler than Qurayzah. When a man of Qurayzah killed a man of an-Nadir, he would be killed. But if a man of an-Nadir killed a man of Qurayzah, a hundred wasq of dates would be paid as blood-money. When Prophethood was bestowed upon the Prophet (ﷺ), a man of an-Nadir killed a man of Qurayzah. They said: Give him to us, we shall kill him. They replied: We have the Prophet (ﷺ) between you and us. So they came to him. Thereupon the following verse was revealed: "If thou judge, judge in equity between them." "In equity" means life for a life. The following verse was then revealed: "Do they seek of a judgment of (the days) ignorance?" Abu Dawud said: Quraizah and al-Nadir were the descendants of Harun the Prophet (peace be upon him)}}
\hadithdefcmd{abudawud}{4495}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ إِيَادٍ - حَدَّثَنَا إِيَادٌ، عَنْ أَبِي رِمْثَةَ، قَالَ انْطَلَقْتُ مَعَ أَبِي نَحْوَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَبِي ‏"‏ ابْنُكَ هَذَا ‏"‏ ‏.‏ قَالَ إِي وَرَبِّ الْكَعْبَةِ قَالَ ‏"‏ حَقًّا ‏"‏ ‏.‏ قَالَ أَشْهَدُ بِهِ ‏.‏ قَالَ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَاحِكًا مِنْ ثَبْتِ شَبَهِي فِي أَبِي وَمِنْ حَلْفِ أَبِي عَلَىَّ ‏.‏ ثُمَّ قَالَ ‏"‏ أَمَا إِنَّهُ لاَ يَجْنِي عَلَيْكَ وَلاَ تَجْنِي عَلَيْهِ ‏"‏ ‏.‏ وَقَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏\}‏\hadithno{4495}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuRimthah: I went to the Prophet (ﷺ) with my father. The Messenger of Allah (ﷺ) then asked my father: Is this your son? He replied: Yes, by the Lord of the Ka'bah. He again said: Is it true? He said: I bear witness to it. The Messenger of Allah (ﷺ) then smiled for my resemblance with my father, and for the fact that my father took an oath upon me. He then said: He will not bring evil on you, nor will you bring evil on him. The Messenger of Allah (ﷺ) recited the verse: "No bearer of burdens can bear the burden of another}}
\hadithdefcmd{abudawud}{4496}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الْحَارِثِ بْنِ فُضَيْلٍ، عَنْ سُفْيَانَ بْنِ أَبِي الْعَوْجَاءِ، عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أُصِيبَ بِقَتْلٍ أَوْ خَبْلٍ فَإِنَّهُ يَخْتَارُ إِحْدَى ثَلاَثٍ إِمَّا أَنْ يَقْتَصَّ وَإِمَّا أَنْ يَعْفُوَ وَإِمَّا أَنْ يَأْخُذَ الدِّيَةَ فَإِنْ أَرَادَ الرَّابِعَةَ فَخُذُوا عَلَى يَدَيْهِ وَمَنِ اعْتَدَى بَعْدَ ذَلِكَ فَلَهُ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏\hadithno{4496}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuShurayh al-Khuza'i: The Prophet (ﷺ) said: If a relative of anyone is killed, or if he suffers khabl, which means a wound, he may choose one of the three things: he may retaliate, or forgive, or receive compensation. But if he wishes a fourth (i.e. something more), hold his hands. After this whoever exceeds the limits shall be in grave penalty}}
\hadithdefcmd{abudawud}{4497}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم رُفِعَ إِلَيْهِ شَىْءٌ فِيهِ قِصَاصٌ إِلاَّ أَمَرَ فِيهِ بِالْعَفْوِ ‏.‏\hadithno{4497}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: I never saw the Messenger of Allah (ﷺ) that some dispute which involved retaliation was brought to him but he commanded regarding it for remission}}
\hadithdefcmd{abudawud}{4498}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُتِلَ رَجُلٌ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَرُفِعَ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَدَفَعَهُ إِلَى وَلِيِّ الْمَقْتُولِ فَقَالَ الْقَاتِلُ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا أَرَدْتُ قَتْلَهُ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْوَلِيِّ ‏ "‏ أَمَا إِنَّهُ إِنْ كَانَ صَادِقًا ثُمَّ قَتَلْتَهُ دَخَلْتَ النَّارَ ‏"‏ ‏.‏ قَالَ فَخَلَّى سَبِيلَهُ ‏.‏ قَالَ وَكَانَ مَكْتُوفًا بِنِسْعَةٍ فَخَرَجَ يَجُرُّ نِسْعَتَهُ فَسُمِّيَ ذَا النِّسْعَةِ ‏.‏\hadithno{4498}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: A man was killed in the lifetime of the Prophet (ﷺ). The matter was brought to the Prophet (ﷺ). He entrusted him to the legal guardian of the slain. The slayer said: Messenger of Allah, I swear by Allah, I did not intend to kill him. The Messenger of Allah (ﷺ) said to the legal guardian: Now if he is true and you kill him, you will enter Hell-fire. So he let him go. His hands were tied with a strap. He came out pulling his strap. Hence he was called Dhu an-Nis'ah (possessor of strap)}}
\hadithdefcmd{abudawud}{4499}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ الْجُشَمِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَوْفٍ، حَدَّثَنَا حَمْزَةُ أَبُو عُمَرَ الْعَائِذِيُّ، حَدَّثَنِي عَلْقَمَةُ بْنُ وَائِلٍ، حَدَّثَنِي وَائِلُ بْنُ حُجْرٍ، قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جِيءَ بِرَجُلٍ قَاتِلٍ فِي عُنُقِهِ النِّسْعَةُ قَالَ فَدَعَا وَلِيَّ الْمَقْتُولِ فَقَالَ ‏"‏ أَتَعْفُو ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَتَأْخُذُ الدِّيَةَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَتَقْتُلُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ بِهِ ‏"‏ ‏.‏ فَلَمَّا وَلَّى قَالَ ‏"‏ أَتَعْفُو ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَتَأْخُذُ الدِّيَةَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَتَقْتُلُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ بِهِ ‏"‏ ‏.‏ فَلَمَّا كَانَ فِي الرَّابِعَةِ قَالَ ‏"‏ أَمَا إِنَّكَ إِنْ عَفَوْتَ عَنْهُ يَبُوءُ بِإِثْمِهِ وَإِثْمِ صَاحِبِهِ ‏"‏ ‏.‏ قَالَ فَعَفَا عَنْهُ ‏.‏ قَالَ فَأَنَا رَأَيْتُهُ يَجُرُّ النِّسْعَةَ ‏.‏\hadithno{4499}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim (1680)}\hadithtrans{Narrated Wa'il ibn Hujr: I was with the Prophet (ﷺ) when a man who was a murderer and had a strap round his neck was brought to him. He then called the legal guardian of the victim and asked him: Do you forgive him? He said: No. He asked: Will you accept the blood-money? He said: No. He asked: Will you kill him? He said: Yes. He said: Take him. When he turned his back, he said: Do you forgive him? He said: No. He said: Will you accept the blood-money? He said: No. He said: Will you kill him? He said: Yes. He said: Take him. After repeating all this a fourth time, he said: If you forgive him, he will bear the burden of his own sin and the sin of the victim. He then forgave him. He (the narrator) said: I saw him pulling the strap}}
\hadithdefcmd{abudawud}{4500}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي جَامِعُ بْنُ مَطَرٍ، حَدَّثَنِي عَلْقَمَةُ بْنُ وَائِلٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏\hadithno{4500}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1680)}\hadithtrans{The tradition mentioned above has also been transmitted by 'Alqamah b. Wa'il through a different chain of narrators and to the same effect}}
\hadithdefcmd{abudawud}{4501}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ الْحَجَّاجِ، حَدَّثَنَا يَزِيدُ بْنُ عَطَاءٍ الْوَاسِطِيُّ، عَنْ سِمَاكٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم بِحَبَشِيٍّ فَقَالَ إِنَّ هَذَا قَتَلَ ابْنَ أَخِي ‏.‏ قَالَ ‏"‏ كَيْفَ قَتَلْتَهُ ‏"‏ ‏.‏ قَالَ ضَرَبْتُ رَأْسَهُ بِالْفَأْسِ وَلَمْ أُرِدْ قَتْلَهُ ‏.‏ قَالَ ‏"‏ هَلْ لَكَ مَالٌ تُؤَدِّي دِيَتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَرَأَيْتَ إِنْ أَرْسَلْتُكَ تَسْأَلُ النَّاسَ تَجْمَعُ دِيَتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَمَوَالِيكَ يُعْطُونَكَ دِيَتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ لِلرَّجُلِ ‏"‏ خُذْهُ ‏"‏ ‏.‏ فَخَرَجَ بِهِ لِيَقْتُلَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّهُ إِنْ قَتَلَهُ كَانَ مِثْلَهُ ‏"‏ ‏.‏ فَبَلَغَ بِهِ الرَّجُلُ حَيْثُ يَسْمَعُ قَوْلَهُ فَقَالَ هُوَ ذَا فَمُرْ فِيهِ مَا شِئْتَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ - وَقَالَ مَرَّةً دَعْهُ - يَبُوءُ بِإِثْمِ صَاحِبِهِ وَإِثْمِهِ فَيَكُونَ مِنْ أَصْحَابِ النَّارِ ‏"‏ ‏.‏ قَالَ فَأَرْسَلَهُ ‏.‏\hadithno{4501}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Wa'il (b. Hujr):A man brought an Abyssinian to the Prophet (ﷺ) and said: This man has killed my nephew. He asked: How did you kill him? He replied: I struck his head with axe but I did not intend to kill him. He asked: Have you some money so that you pay his blood-wit? He said: No. He said: What is your opinion if I send you so that you ask the people (for money) and thus collect your blood-wit? He said: No. He asked : Will your masters give you his blood-wit (to pay his relatives)? He said: No. He said to the man. Take him. So he brought him out to kill him. The Messenger of Allah (ﷺ) said: If he kill him, he will be like him. This (statement) reached the man where he was listening to his statement. He said: He is here, order regarding him as you like. The Messenger of Allah (ﷺ) said: Leave him alone. And he once said: He will bear the burden of the sin of the slain and that of his own and thus he will become one of the Companions of Hell. So he let him go}}
\hadithdefcmd{abudawud}{4502}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، قَالَ كُنَّا مَعَ عُثْمَانَ وَهُوَ مَحْصُورٌ فِي الدَّارِ وَكَانَ فِي الدَّارِ مَدْخَلٌ مَنْ دَخَلَهُ سَمِعَ كَلاَمَ مَنْ عَلَى الْبَلاَطِ فَدَخَلَهُ عُثْمَانُ فَخَرَجَ إِلَيْنَا وَهُوَ مُتَغَيِّرٌ لَوْنُهُ فَقَالَ إِنَّهُمْ لَيَتَوَاعَدُونَنِي بِالْقَتْلِ آنِفًا ‏.‏ قُلْنَا يَكْفِيكَهُمُ اللَّهُ يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ قَالَ وَلِمَ يَقْتُلُونَنِي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِإِحْدَى ثَلاَثٍ كُفْرٌ بَعْدَ إِسْلاَمٍ أَوْ زِنًا بَعْدَ إِحْصَانٍ أَوْ قَتْلُ نَفْسٍ بِغَيْرِ نَفْسٍ ‏"‏ ‏.‏ فَوَاللَّهِ مَا زَنَيْتُ فِي جَاهِلِيَّةٍ وَلاَ إِسْلاَمٍ قَطُّ وَلاَ أَحْبَبْتُ أَنَّ لِي بِدِينِي بَدَلاً مُنْذُ هَدَانِي اللَّهُ وَلاَ قَتَلْتُ نَفْسًا فَبِمَ يَقْتُلُونَنِي قَالَ أَبُو دَاوُدَ عُثْمَانُ وَأَبُو بَكْرٍ رضى الله عنهما تَرَكَا الْخَمْرَ فِي الْجَاهِلِيَّةِ ‏.‏\hadithno{4502}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuUmamah ibn Sahl: We were with Uthman when he was besieged in the house. There was an entrance to the house. He who entered it heard the speech of those who were in the Bilat. Uthman then entered it. He came out to us, looking pale. He said: They are threatening to kill me now. We said: Allah will be sufficient for you against them, Commander of the Faithful! He asked: Why kill me? I heard the Messenger of Allah (ﷺ) say: It is not lawful to kill a man who is a Muslim except for one of the three reasons: Kufr (disbelief) after accepting Islam, fornication after marriage, or wrongfully killing someone, for which he may be killed. I swear by Allah, I have not committed fornication before or after the coming of Islam, nor did I ever want another religion for me instead of my religion since Allah gave guidance to me, nor have I killed anyone. So for what reason do you want to kill me? Abu Dawud said: 'Uthman and Abu Bakr (Allah be pleased with them) abandoned drinking wine in pre-Islamic times}}
\hadithdefcmd{abudawud}{4503}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، فَحَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ الزُّبَيْرِ، قَالَ سَمِعْتُ زِيَادَ بْنَ ضُمَيْرَةَ الضَّمْرِيَّ، ح وَحَدَّثَنَا وَهْبُ بْنُ بَيَانٍ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، أَنَّهُ سَمِعَ زِيَادَ بْنَ سَعْدِ بْنِ ضُمَيْرَةَ السُّلَمِيَّ، - وَهَذَا حَدِيثُ وَهْبٍ وَهُوَ أَتَمُّ - يُحَدِّثُ عُرْوَةَ بْنَ الزُّبَيْرِ عَنْ أَبِيهِ - قَالَ مُوسَى - وَجَدِّهِ وَكَانَا شَهِدَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حُنَيْنًا - ثُمَّ رَجَعْنَا إِلَى حَدِيثِ وَهْبٍ - أَنَّ مُحَلِّمَ بْنَ جَثَّامَةَ اللَّيْثِيَّ قَتَلَ رَجُلاً مِنْ أَشْجَعَ فِي الإِسْلاَمِ وَذَلِكَ أَوَّلُ غِيَرٍ قَضَى بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَكَلَّمَ عُيَيْنَةُ فِي قَتْلِ الأَشْجَعِيِّ لأَنَّهُ مِنْ غَطَفَانَ وَتَكَلَّمَ الأَقْرَعُ بْنُ حَابِسٍ دُونَ مُحَلِّمٍ لأَنَّهُ مِنْ خِنْدِفَ فَارْتَفَعَتِ الأَصْوَاتُ وَكَثُرَتِ الْخُصُومَةُ وَاللَّغَطُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عُيَيْنَةُ أَلاَ تَقْبَلُ الْغِيَرَ ‏"‏ ‏.‏ فَقَالَ عُيَيْنَةُ لاَ وَاللَّهِ حَتَّى أُدْخِلَ عَلَى نِسَائِهِ مِنَ الْحَرْبِ وَالْحَزَنِ مَا أَدْخَلَ عَلَى نِسَائِي ‏.‏ قَالَ ثُمَّ ارْتَفَعَتِ الأَصْوَاتُ وَكَثُرَتِ الْخُصُومَةُ وَاللَّغَطُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عُيَيْنَةُ أَلاَ تَقْبَلُ الْغِيَرَ ‏"‏ ‏.‏ فَقَالَ عُيَيْنَةُ مِثْلَ ذَلِكَ أَيْضًا إِلَى أَنْ قَامَ رَجُلٌ مِنْ بَنِي لَيْثٍ يُقَالُ لَهُ مُكَيْتِلٌ عَلَيْهِ شِكَّةٌ وَفِي يَدِهِ دَرَقَةٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَجِدْ لِمَا فَعَلَ هَذَا فِي غُرَّةِ الإِسْلاَمِ مَثَلاً إِلاَّ غَنَمًا وَرَدَتْ فَرُمِيَ أَوَّلُهَا فَنَفَرَ آخِرُهَا اسْنُنِ الْيَوْمَ وَغَيِّرْ غَدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَمْسُونَ فِي فَوْرِنَا هَذَا وَخَمْسُونَ إِذَا رَجَعْنَا إِلَى الْمَدِينَةِ ‏"‏ ‏.‏ وَذَلِكَ فِي بَعْضِ أَسْفَارِهِ وَمُحَلِّمٌ رَجُلٌ طَوِيلٌ آدَمُ وَهُوَ فِي طَرَفِ النَّاسِ فَلَمْ يَزَالُوا حَتَّى تَخَلَّصَ فَجَلَسَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَيْنَاهُ تَدْمَعَانِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ فَعَلْتُ الَّذِي بَلَغَكَ وَإِنِّي أَتُوبُ إِلَى اللَّهِ تَبَارَكَ وَتَعَالَى فَاسْتَغْفِرِ اللَّهَ عَزَّ وَجَلَّ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَقَتَلْتَهُ بِسِلاَحِكَ فِي غُرَّةِ الإِسْلاَمِ اللَّهُمَّ لاَ تَغْفِرْ لِمُحَلِّمٍ ‏"‏ ‏.‏ بِصَوْتٍ عَالٍ زَادَ أَبُو سَلَمَةَ فَقَامَ وَإِنَّهُ لَيَتَلَقَّى دُمُوعَهُ بِطَرَفِ رِدَائِهِ قَالَ ابْنُ إِسْحَاقَ فَزَعَمَ قَوْمُهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَغْفَرَ لَهُ بَعْدَ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ النَّضْرُ بْنُ شُمَيْلٍ الْغِيَرُ الدِّيَةُ ‏.‏\hadithno{4503}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ziyad ibn Sa'd ibn Dumayrah as-Sulami: On the authority of his father (Sa'd) and his grandfather (Dumayrah) (according to Musa's version) who were present in the battle of Hunayn with the Messenger of Allah (ﷺ): After the advent of Islam, Muhallam ibn Jaththamah al-Laythi killed a man of Ashja'. That was the first blood-money decided by the Messenger of Allah (ﷺ) (for payment). Uyaynah spoke about the killing of al-Ashja'i, for he belonged to Ghatafan, and al-Aqra' ibn Habis spoke on behalf of Muhallam, for he belonged to Khunduf. The voices rose high, and the dispute and noise grew. So the Messenger of Allah (ﷺ) said: Do you not accept blood-money, Uyaynah? Uyaynah then said: No, I swear by Allah, until I cause his women to suffer the same fighting and grief as he caused my women to suffer. Again the voices rose high, and the dispute and noise grew. The Messenger of Allah (ﷺ) said: Do you not accept the blood-money Uyaynah? Uyaynah gave the same reply as before, and a man of Banu Layth called Mukaytil stood up. He had a weapon and a skin shield in his hand. He said: I do not find in the beginning of Islam any illustration for what he has done except the one that "some sheep came on, and those in the front were shot; hence those in the rear ran away". (The other example is that) "make a law today and change it." The Messenger of Allah (ﷺ) said: Fifty (camels) here immediately and fifty when we return to Medina. This happened during some of his journeys. Muhallam was a tall man of dark complexion. He was with the people. They continued (to make effort for him) until he was released. He sat before the Messenger of Allah (ﷺ), with his eyes flowing. He said: Messenger of Allah! I have done (the act) of which you have been informed. I repent to Allah, the Exalted, so ask Allah's forgiveness for me. Messenger of Allah! The Messenger of Allah (ﷺ) then said: Did you kill him with your weapon at the beginning of Islam. O Allah! do not forgive Muhallam. He said these words loudly. AbuSalamah added: He (Muhallam) then got up while he was wiping his tears with the end of his garment. Ibn Ishaq said: His people alleged that the Messenger of Allah (ﷺ) asked forgiveness for him after that. Abu Dawud said: Al-Nadr b. Shumail said: al-ghiyar means blood-wit}}
\hadithdefcmd{abudawud}{4504}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، قَالَ سَمِعْتُ أَبَا شُرَيْحٍ الْكَعْبِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ إِنَّكُمْ يَا مَعْشَرَ خُزَاعَةَ قَتَلْتُمْ هَذَا الْقَتِيلَ مِنْ هُذَيْلٍ وَإِنِّي عَاقِلُهُ فَمَنْ قُتِلَ لَهُ بَعْدَ مَقَالَتِي هَذِهِ قَتِيلٌ فَأَهْلُهُ بَيْنَ خِيرَتَيْنِ أَنْ يَأْخُذُوا الْعَقْلَ أَوْ يَقْتُلُوا ‏"‏ ‏.‏\hadithno{4504}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuShurayb al-Ka'bi: The Prophet (ﷺ) said: Then you, Khuza'ah, have killed this man of Hudhayl, but I will pay his blood-wit. After these words of mine if a man of anyone is killed, his people will have a choice to accept blood-wit or to kill him}}
\hadithdefcmd{abudawud}{4505}{حَدَّثَنَا عَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، أَخْبَرَنَا أَبِي، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى، ح وَحَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي أَبُو دَاوُدَ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ لَمَّا فُتِحَتْ مَكَّةُ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ قُتِلَ لَهُ قَتِيلٌ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يُودَى أَوْ يُقَادَ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ يُقَالُ لَهُ أَبُو شَاهٍ فَقَالَ يَا رَسُولَ اللَّهِ اكْتُبْ لِي - قَالَ الْعَبَّاسُ اكْتُبُوا لِي - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ وَهَذَا لَفْظُ حَدِيثِ أَحْمَدَ ‏.‏ قَالَ أَبُو دَاوُدَ اكْتُبُوا لِي يَعْنِي خُطْبَةَ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4505}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2434، 6880) Sahih Muslim (1355)}\hadithtrans{Narrated Abu Hurairah:When Mecca was conquered, the Messenger of Allah (ﷺ) got up and said: If a relative of anyone is killed, he will have a choice between two : he (the slayer) will either pay the blood-wit or he will be killed. A man of the Yemen called Abu Shah stood up and said: Write for me, Messenger of Allah. The narrator al-'Abbas (b. al-Walid) said: Write to me, (you people). The Messenger of Allah (ﷺ) said: Write (you people), for Abu Shah. These are the wordings of the tradition of Ahmad. Abu Dawud said: Write (you people), for me, that is, the address of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4506}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقْتَلُ مُؤْمِنٌ بِكَافِرٍ وَمَنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا دُفِعَ إِلَى أَوْلِيَاءِ الْمَقْتُولِ فَإِنْ شَاءُوا قَتَلُوهُ وَإِنْ شَاءُوا أَخَذُوا الدِّيَةَ ‏"‏ ‏.‏\hadithno{4506}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Shu'aib: On his father's authority said that his grandfather reported the Prophet (ﷺ) said: A believer will not be killed for an infidel. If anyone kills a man deliberately, he is to be handed over to the relatives of the one who has been killed. If they wish, they may kill, but if they wish, they may accept blood-wit}}
\hadithdefcmd{abudawud}{4507}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا مَطَرٌ الْوَرَّاقُ، - وَأَحْسَبُهُ - عَنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ أُعْفِي مَنْ قَتَلَ بَعْدَ أَخْذِهِ الدِّيَةَ ‏"‏ ‏.‏\hadithno{4507}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: I will not forgive anyone who kills after accepting blood-wit}}
\hadithdefcmd{abudawud}{4508}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ امْرَأَةً، يَهُودِيَّةً أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِشَاةٍ مَسْمُومَةٍ فَأَكَلَ مِنْهَا فَجِيءَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهَا عَنْ ذَلِكَ فَقَالَتْ أَرَدْتُ لأَقْتُلَكَ ‏.‏ فَقَالَ ‏"‏ مَا كَانَ اللَّهُ لِيُسَلِّطَكِ عَلَى ذَلِكَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ عَلَىَّ ‏"‏ ‏.‏ قَالَ فَقَالُوا أَلاَ نَقْتُلُهَا قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَمَا زِلْتُ أَعْرِفُهَا فِي لَهَوَاتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4508}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari (2617) Sahih Muslim (2190)}\hadithtrans{Narrated Anas bin Malik:A Jewess brought a poisoned sheep to the Messenger of Allah (ﷺ), and he ate of it. She was then brought to the Messenger of Allah (ﷺ) who asked her about it. She said: I intended to kill you. He said: Allah will not give you control over it ; or he said : over me. They (the Companions) said: Should we not kill her ? He said: No. He (Anas) said: I always found it in the uvula of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{4509}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا عَبَّاُدُ بْنُ الْعَوَّامِ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّادٌ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ - قَالَ هَارُونُ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ امْرَأَةً، مِنَ الْيَهُودِ أَهْدَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم شَاةً مَسْمُومَةً - قَالَ - فَمَا عَرَضَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ هَذِهِ أُخْتُ مَرْحَبٍ الْيَهُودِيَّةُ الَّتِي سَمَّتِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{4509}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: A Jewess presented a poisoned sheep to the Prophet (ﷺ), but the Prophet (ﷺ) did not interfere with he. Abu Dawud said: The Jewess who poisoned the Prophet (ﷺ) was sister of Marhab}}
\hadithdefcmd{abudawud}{4510}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ كَانَ جَابِرُ بْنُ عَبْدِ اللَّهِ يُحَدِّثُ أَنَّ يَهُودِيَّةً، مِنْ أَهْلِ خَيْبَرَ سَمَّتْ شَاةً مَصْلِيَّةً ثُمَّ أَهْدَتْهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الذِّرَاعَ فَأَكَلَ مِنْهَا وَأَكَلَ رَهْطٌ مِنْ أَصْحَابِهِ مَعَهُ ثُمَّ قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْفَعُوا أَيْدِيَكُمْ ‏"‏ ‏.‏ وَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَهُودِيَّةِ فَدَعَاهَا فَقَالَ لَهَا ‏"‏ أَسَمَمْتِ هَذِهِ الشَّاةَ ‏"‏ ‏.‏ قَالَتِ الْيَهُودِيَّةُ مَنْ أَخْبَرَكَ قَالَ ‏"‏ أَخْبَرَتْنِي هَذِهِ فِي يَدِي ‏"‏ ‏.‏ لِلذِّرَاعِ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَرَدْتِ إِلَى ذَلِكَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ إِنْ كَانَ نَبِيًّا فَلَنْ يَضُرَّهُ وَإِنْ لَمْ يَكُنِ اسْتَرَحْنَا مِنْهُ ‏.‏ فَعَفَا عَنْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يُعَاقِبْهَا وَتُوُفِّيَ بَعْضُ أَصْحَابِهِ الَّذِينَ أَكَلُوا مِنَ الشَّاةِ وَاحْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى كَاهِلِهِ مِنْ أَجْلِ الَّذِي أَكَلَ مِنَ الشَّاةِ حَجَمَهُ أَبُو هِنْدٍ بِالْقَرْنِ وَالشَّفْرَةِ وَهُوَ مَوْلًى لِبَنِي بَيَاضَةَ مِنَ الأَنْصَارِ ‏.‏\hadithno{4510}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Shihab: Jabir ibn Abdullah used to say that a Jewess from the inhabitants of Khaybar poisoned a roasted sheep and presented it to the Messenger of Allah (ﷺ) who took its foreleg and ate from it. A group of his companions also ate with him. The Messenger of Allah (ﷺ) then said: Take your hands away (from the food). The Messenger of Allah (ﷺ) then sent someone to the Jewess and he called her. He said to her: Have you poisoned this sheep? The Jewess replied: Who has informed you? He said: This foreleg which I have in my hand has informed me. She said: Yes. He said: What did you intend by it? She said: I thought if you were a prophet, it would not harm you; if you were not a prophet, we should rid ourselves of him (i.e. the Prophet). The Messenger of Allah (ﷺ) then forgave her, and did not punish her. But some of his companions who ate it, died. The Messenger of Allah (ﷺ) had himself cupped on his shoulder on account of that which he had eaten from the sheep. AbuHind cupped him with the horn and knife. He was a client of Banu Bayadah from the Ansar}}
\hadithdefcmd{abudawud}{4511}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، حَدَّثَنَا خَالِدٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَتْ لَهُ يَهُودِيَّةٌ بِخَيْبَرَ شَاةً مَصْلِيَّةً نَحْوَ حَدِيثِ جَابِرٍ قَالَ فَمَاتَ بِشْرُ بْنُ الْبَرَاءِ بْنِ مَعْرُورٍ الأَنْصَارِيُّ فَأَرْسَلَ إِلَى الْيَهُودِيَّةِ ‏ "‏ مَا حَمَلَكِ عَلَى الَّذِي صَنَعْتِ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ جَابِرٍ فَأَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُتِلَتْ وَلَمْ يَذْكُرْ أَمْرَ الْحِجَامَةِ ‏.‏\hadithno{4511}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuSalamah: A Jewess presented a roasted sheep to the Messenger of Allah (ﷺ) at Khaybar. He then mentioned the rest of the tradition like that of Jabir (No. 4495). He said: Then Bashir ibn al-Bara' ibn Ma'rur al-Ansari died. He sent someone to call on the Jewess, and said to her (when she came): What motivated you to do the work you have done? He then mentioned the rest of the tradition similar to the one mentioned by Jabir (No. 4495). The Messenger of Allah (ﷺ) then ordered regarding her and she was killed. But he (AbuSalamah) did not mention the matter of cupping}}
\hadithdefcmd{abudawud}{4512}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْبَلُ الْهَدِيَّةَ وَلاَ يَأْكُلُ الصَّدَقَةَ ‏.‏ وَحَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ فِي مَوْضِعٍ آخَرَ عَنْ خَالِدٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ وَلَمْ يَذْكُرْ أَبَا هُرَيْرَةَ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْبَلُ الْهَدِيَّةَ وَلاَ يَأْكُلُ الصَّدَقَةَ ‏.‏ زَادَ فَأَهْدَتْ لَهُ يَهُودِيَّةٌ بِخَيْبَرَ شَاةً مَصْلِيَّةً سَمَّتْهَا فَأَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا وَأَكَلَ الْقَوْمُ فَقَالَ ‏"‏ ارْفَعُوا أَيْدِيَكُمْ فَإِنَّهَا أَخْبَرَتْنِي أَنَّهَا مَسْمُومَةٌ ‏"‏ ‏.‏ فَمَاتَ بِشْرُ بْنُ الْبَرَاءِ بْنِ مَعْرُورٍ الأَنْصَارِيُّ فَأَرْسَلَ إِلَى الْيَهُودِيَّةِ ‏"‏ مَا حَمَلَكِ عَلَى الَّذِي صَنَعْتِ ‏"‏ ‏.‏ قَالَتْ إِنْ كُنْتَ نَبِيًّا لَمْ يَضُرَّكَ الَّذِي صَنَعْتُ وَإِنْ كُنْتَ مَلِكًا أَرَحْتُ النَّاسَ مِنْكَ ‏.‏ فَأَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُتِلَتْ ثُمَّ قَالَ فِي وَجَعِهِ الَّذِي مَاتَ فِيهِ ‏"‏ مَا زِلْتُ أَجِدُ مِنَ الأَكْلَةِ الَّتِي أَكَلْتُ بِخَيْبَرَ فَهَذَا أَوَانُ قَطَعَتْ أَبْهَرِي ‏"‏ ‏.‏\hadithno{4512}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) would accept a present, but would not accept alms (sadaqah). And Wahb bin Baqiyyah narrated to us, elsewhere, from Khalid, from Muhammad ibn Amr said on the authority of AbuSalamah, and he did not mention the name of Abu Hurairah: The Messenger of Allah (ﷺ) used to accept presents but not alms (sadaqah). This version adds: So a Jewess presented him at Khaybar with a roasted sheep which she had poisoned. The Messenger of Allah (ﷺ) ate of it and the people also ate. He then said: Take away your hands (from the food), for it has informed me that it is poisoned. Bishr ibn al-Bara' ibn Ma'rur al-Ansari died. So he (the Prophet) sent for the Jewess (and said to her): What motivated you to do the work you have done? She said: If you were a prophet, it would not harm you; but if you were a king, I should rid the people of you. The Messenger of Allah (ﷺ) then ordered regarding her and she was killed. He then said about the pain of which he died: I continued to feel pain from the morsel which I had eaten at Khaybar. This is the time when it has cut off my aorta}}
\hadithdefcmd{abudawud}{4513}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ أُمَّ مُبَشِّرٍ، قَالَتْ لِلنَّبِيِّ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ مَا يُتَّهَمُ بِكَ يَا رَسُولَ اللَّهِ فَإِنِّي لاَ أَتَّهِمُ بِابْنِي شَيْئًا إِلاَّ الشَّاةَ الْمَسْمُومَةَ الَّتِي أَكَلَ مَعَكَ بِخَيْبَرَ ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَأَنَا لاَ أَتَّهِمُ بِنَفْسِي إِلاَّ ذَلِكَ فَهَذَا أَوَانُ قَطَعَتْ أَبْهَرِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرُبَّمَا حَدَّثَ عَبْدُ الرَّزَّاقِ بِهَذَا الْحَدِيثِ مُرْسَلاً عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرُبَّمَا حَدَّثَ بِهِ عَنِ الزُّهْرِيِّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ وَذَكَرَ عَبْدُ الرَّزَّاقِ أَنَّ مَعْمَرًا كَانَ يُحَدِّثُهُمْ بِالْحَدِيثِ مَرَّةً مُرْسَلاً فَيَكْتُبُونَهُ وَيُحَدِّثُهُمْ مَرَّةً بِهِ فَيُسْنِدُهُ فَيَكْتُبُونَهُ وَكُلٌّ صَحِيحٌ عِنْدَنَا قَالَ عَبْدُ الرَّزَّاقِ فَلَمَّا قَدِمَ ابْنُ الْمُبَارَكِ عَلَى مَعْمَرٍ أَسْنَدَ لَهُ مَعْمَرٌ أَحَادِيثَ كَانَ يُوقِفُهَا ‏.‏\hadithno{4513}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn Ka'b b. Malik: On the authority of his father: Umm Mubashshir said to the Prophet (ﷺ) during the sickness of which he died: What do you think about your illness, Messenger of Allah (ﷺ)? I do not think about the illness of my son except the poisoned sheep of which he had eaten with you at Khaybar. The Prophet (ﷺ) said: And I do not think about my illness except that. This is the time when it cut off my aorta. Abu Dawud said: Sometime 'Abd al-Razzaq transmitted this tradition, omitting the link of the Companion, from Ma'mar, from al-Zuhri, from the Prophet (ﷺ), and sometimes he transmitted it from al-Zuhri from 'Abd al-Rahman b. Ka'b b. Malik, 'Abd al-Rahman mentioned that Ma'mar sometimes transmitted the tradition in a mursal form (omitting the link of the Companion), and they recorded it. And all this is correct with us. 'Abd al-Razzaq said: When Ibn al-Mubarak came to Ma'mar, he transmitted the traditions in a musnad form (with a perfect chain) which he transmitted as mauquf traditions (statements of the Companions and not of the Prophet)}}
\hadithdefcmd{abudawud}{4514}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، حَدَّثَنَا رَبَاحٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أُمِّهِ، أَنَّ أُمَّ مُبَشِّرٍ، - قَالَ أَبُو سَعِيدِ بْنُ الأَعْرَابِيِّ كَذَا قَالَ عَنْ أُمِّهِ، وَالصَّوَابُ، عَنْ أَبِيهِ، عَنْ أُمِّ مُبَشِّرٍ، - دَخَلَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ مَعْنَى حَدِيثِ مَخْلَدِ بْنِ خَالِدٍ نَحْوَ حَدِيثِ جَابِرٍ قَالَ فَمَاتَ بِشْرُ بْنُ الْبَرَاءِ بْنِ مَعْرُورٍ فَأَرْسَلَ إِلَى الْيَهُودِيَّةِ فَقَالَ ‏ "‏ مَا حَمَلَكِ عَلَى الَّذِي صَنَعْتِ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ جَابِرٍ فَأَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُتِلَتْ وَلَمْ يَذْكُرِ الْحِجَامَةَ ‏.‏\hadithno{4514}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abd al-Rahman b. 'Abd Allah b. Ka'b b. Malik :On the authority of his mother than Umm Mubashshir said (Abu Sa'id b. al-A'rabi said: So he said it on the authority of his mother ; what is correct is: on the authority of his father, instead of his mother): I entered upon the Prophet (ﷺ). He then mentioned the tradition of Makhlad b. Khalid in a way similar to the tradition of Jabir. The narrator said: Then Bishr b. al-Bara' b. Ma'rur died. So he (the Prophet) sent for the Jewess and said: What did motivate you for your work you have done ? He (the narrator) then mentioned the rest of the tradition like the tradition of Jabir. The Messenger of Allah (ﷺ) ordered regarding her and she was killed. He (the narrator in this version) did not mention cupping}}
\hadithdefcmd{abudawud}{4515}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ عَبْدَهُ قَتَلْنَاهُ وَمَنْ جَدَعَ عَبْدَهُ جَدَعْنَاهُ ‏"‏ ‏.‏\hadithno{4515}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{Narrated Samurah: The Prophet (ﷺ) Said: If anyone kills his slave, we shall kill him, and if anyone cuts off the nose of his slave, we shall cut off his nose}}
\hadithdefcmd{abudawud}{4516}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، بِإِسْنَادِهِ مِثْلَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَصَى عَبَدَهُ خَصَيْنَاهُ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ مِثْلَ حَدِيثِ شُعْبَةَ وَحَمَّادٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ أَبُو دَاوُدَ الطَّيَالِسِيُّ عَنْ هِشَامٍ مِثْلَ حَدِيثِ مُعَاذٍ ‏.‏\hadithno{4516}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Qatadah: Through the same chain of narrators as mentioned before, i.e. Samurah reported the Messenger of Allah (ﷺ) as saying: If anyone castrates his slave, we shall castrate him. He then mentioned the rest of the tradition like that of Sh'ubah and Hammad. Abu Dawud said: Abu Dawud al-Tayalisi transmitted it from Hisham like the tradition of Mu'adh}}
\hadithdefcmd{abudawud}{4517}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، بِإِسْنَادِ شُعْبَةَ مِثْلَهُ زَادَ ثُمَّ إِنَّ الْحَسَنَ نَسِيَ هَذَا الْحَدِيثَ فَكَانَ يَقُولُ ‏ "‏ لاَ يُقْتَلُ حُرٌّ بِعَبْدٍ ‏"‏ ‏.‏\hadithno{4517}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Qatadah transmitted the tradition mentioned above through a chain of narrators like that of Shu'bah. This version adds:Then al-Hasan forgot this tradition, and he used to say: A free man is not to be killed for a slave}}
\hadithdefcmd{abudawud}{4518}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، قَالَ لاَ يُقَادُ الْحُرُّ بِالْعَبْدِ ‏.‏\hadithno{4518}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hisham, from Qatadah, from Al-Hasan, who said:"A free man should not be subjected to retaliation in return for a slave}}
\hadithdefcmd{abudawud}{4519}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ بْنِ تَسْنِيمٍ الْعَتَكِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا سَوَّارٌ أَبُو حَمْزَةَ، حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ رَجُلٌ مُسْتَصْرِخٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ جَارِيَةٌ لَهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ وَيْحَكَ مَا لَكَ ‏"‏ ‏.‏ قَالَ شَرًّا أَبْصَرَ لِسَيِّدِهِ جَارِيَةً لَهُ فَغَارَ فَجَبَّ مَذَاكِيرَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَىَّ بِالرَّجُلِ ‏"‏ ‏.‏ فَطُلِبَ فَلَمْ يُقْدَرْ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَأَنْتَ حُرٌّ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ عَلَى مَنْ نُصْرَتِي قَالَ ‏"‏ عَلَى كُلِّ مُؤْمِنٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ كُلِّ مُسْلِمٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي عُتِقَ كَانَ اسْمُهُ رَوْحُ بْنُ دِينَارٍ ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي جَبَّهُ زِنْبَاعٌ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا زِنْبَاعٌ أَبُو رَوْحٍ كَانَ مَوْلَى الْعَبْدِ ‏.‏\hadithno{4519}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Shu'aib: On his father's authority, said that his grandfather told that a A man came to the Prophet (ﷺ) crying for help. He said: His slave-girl, Messenger of Allah! He said: Woe to you, what happened with you ? He said that it was an evil one. He saw the slave-girl of his master; he became jealous of him, and cut off his penis. The Messenger of Allah (ﷺ) said: Bring the man to me. The man was called, but people could not get control over him. The Messenger of Allah (ﷺ) then said: Go away, you are free. He asked: Messenger of Allah! upon whom does my help lie? He replied: On every believer, or he said: On every Muslim. Abu Dawud said: The name of the man who was emancipated was Rawh b. Dinar Abu Dawud said: The man who cut off the penis was Zinba' Abu Dawud said: The Zinba' Abu Rawh was master of the slave}}
\hadithdefcmd{abudawud}{4520}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بَشِيرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، وَرَافِعِ بْنِ خَدِيجٍ، أَنَّ مُحَيِّصَةَ بْنَ مَسْعُودٍ، وَعَبْدَ اللَّهِ بْنَ سَهْلٍ، انْطَلَقَا قِبَلَ خَيْبَرَ فَتَفَرَّقَا فِي النَّخْلِ فَقُتِلَ عَبْدُ اللَّهِ بْنُ سَهْلٍ فَاتَّهَمُوا الْيَهُودَ فَجَاءَ أَخُوهُ عَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَابْنَا عَمِّهِ حُوَيِّصَةُ وَمُحَيِّصَةُ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَتَكَلَّمَ عَبْدُ الرَّحْمَنِ فِي أَمْرِ أَخِيهِ وَهُوَ أَصْغَرُهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْكُبْرَ الْكُبْرَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ لِيَبْدَإِ الأَكْبَرُ ‏"‏ ‏.‏ فَتَكَلَّمَا فِي أَمْرِ صَاحِبِهِمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُقْسِمُ خَمْسُونَ مِنْكُمْ عَلَى رَجُلٍ مِنْهُمْ فَيُدْفَعُ بِرُمَّتِهِ ‏"‏ ‏.‏ قَالُوا أَمْرٌ لَمْ نَشْهَدْهُ كَيْفَ نَحْلِفُ قَالَ ‏"‏ فَتُبَرِّئُكُمْ يَهُودُ بِأَيْمَانِ خَمْسِينَ مِنْهُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ قَوْمٌ كُفَّارٌ ‏.‏ قَالَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قِبَلِهِ ‏.‏ قَالَ قَالَ سَهْلٌ دَخَلْتُ مِرْبَدًا لَهُمْ يَوْمًا فَرَكَضَتْنِي نَاقَةٌ مِنْ تِلْكَ الإِبِلِ رَكْضَةً بِرِجْلِهَا ‏.‏ قَالَ حَمَّادٌ هَذَا أَوْ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ بِشْرُ بْنُ الْمُفَضَّلِ وَمَالِكٌ عَنْ يَحْيَى بْنِ سَعِيدٍ قَالَ فِيهِ ‏"‏ أَتَحْلِفُونَ خَمْسِينَ يَمِينًا وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ أَوْ قَاتِلِكُمْ ‏"‏ وَلَمْ يَذْكُرْ بِشْرٌ دَمًا وَقَالَ عَبْدَةُ عَنْ يَحْيَى كَمَا قَالَ حَمَّادٌ وَرَوَاهُ ابْنُ عُيَيْنَةَ عَنْ يَحْيَى فَبَدَأَ بِقَوْلِهِ ‏"‏ تُبَرِّئُكُمْ يَهُودُ بِخَمْسِينَ يَمِينًا يَحْلِفُونَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الاِسْتِحْقَاقَ قَالَ أَبُو دَاوُدَ وَهَذَا وَهَمٌ مِنِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{4520}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6143) Sahih Muslim (1669)}\hadithtrans{Narrated Sahl b. Abi Hathmah and Rafi' b. Khadij: Muhayyasah b. Mas'ud and 'Abd Allah b. Sahl came to Khaibar and parted (from each other) among palm trees. 'Abd Allah b. Sahl was killed. The Jews were blamed (for the murder). 'Abd al-Rahman b. Sahl and Huwayyasah and Muhayyasah, the sons of his uncle (Mas'ud) came to the Prophet (ﷺ). 'Abd al-Rahman, who was the youngest, spoke about his brother, but the Messenger of Allah (ﷺ) said to him: (Respect) the elder, (respect) the elder or he said: Let the eldest begin. They then spoke about their friend and the Messenger of Allah (ﷺ) said: Fifty of you should take oaths regarding a man from them (the Jews) and he should be entrusted (to him) with his rope (in his neck). They said: It is a matter which we did not see. How can we take oaths ? He said: The Jews exonerate themselves by the oaths of fifty of them. They said: Messenger of Allah! they are a people who are infidels. So the Messenger of Allah (ﷺ) paid them bloodwit himself. Sahl said: Once I entered the resting place of their camels, and the she-camel struck me with her lef. Hammad said this or (something) similar to it. Abu Dawud said: Another version transmitted by Yahya b. Sa'id has: Would you swear fifty oaths and make you claim regarding your friend or your slain man ? Bishr, the transmitter, did mention blood. 'Abdah transmitted it from Yahya as transmitted by Hammad. Ibn 'Uyainah has also transmitted it from Yahya, and began with his words: The Jew will exonerate themselves by fifty oaths which they will swear. He did not mention the claim. Abu Dawud said: This is a misunderstanding on the part of Ibn 'Uyainah}}
\hadithdefcmd{abudawud}{4521}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، عَنْ أَبِي لَيْلَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَهْلٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ أَخْبَرَهُ هُوَ، وَرِجَالٌ، مِنْ كُبَرَاءِ قَوْمِهِ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ خَرَجَا إِلَى خَيْبَرَ مِنْ جَهْدٍ أَصَابَهُمْ فَأُتِيَ مُحَيِّصَةُ فَأُخْبِرَ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَدْ قُتِلَ وَطُرِحَ فِي فَقِيرٍ أَوْ عَيْنٍ فَأَتَى يَهُودَ فَقَالَ أَنْتُمْ وَاللَّهِ قَتَلْتُمُوهُ ‏.‏ قَالُوا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَأَقْبَلَ حَتَّى قَدِمَ عَلَى قَوْمِهِ فَذَكَرَ لَهُمْ ذَلِكَ ثُمَّ أَقْبَلَ هُوَ وَأَخُوهُ حُوَيِّصَةُ - وَهُوَ أَكْبَرُ مِنْهُ - وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ فَذَهَبَ مُحَيِّصَةُ لِيَتَكَلَّمَ وَهُوَ الَّذِي كَانَ بِخَيْبَرَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَبِّرْ كَبِّرْ ‏"‏ ‏.‏ يُرِيدُ السِّنَّ فَتَكَلَّمَ حُوَيِّصَةُ ثُمَّ تَكَلَّمَ مُحَيِّصَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِمَّا أَنْ يَدُوا صَاحِبَكُمْ وَإِمَّا أَنْ يُؤْذَنُوا بِحَرْبٍ ‏"‏ ‏.‏ فَكَتَبَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ فَكَتَبُوا إِنَّا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحُوَيِّصَةَ وَمُحَيِّصَةَ وَعَبْدِ الرَّحْمَنِ ‏"‏ أَتَحْلِفُونَ وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَتَحْلِفُ لَكُمْ يَهُودُ ‏"‏ ‏.‏ قَالُوا لَيْسُوا مُسْلِمِينَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ فَبَعَثَ إِلَيْهِمْ مِائَةَ نَاقَةٍ حَتَّى أُدْخِلَتْ عَلَيْهِمُ الدَّارَ ‏.‏ قَالَ سَهْلٌ لَقَدْ رَكَضَتْنِي مِنْهَا نَاقَةٌ حَمْرَاءُ ‏.‏\hadithno{4521}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sahl b. Abi Hathmah and some senior men of the tribe told that 'Abd Allah b. Abi Sahl and Muhayyasah came to Khaibar on account of the calamity (i.e. famine) that befall them. Muhayyasah came and told the 'Abd Allah b. Sahl had been killed and thrown in a well or stream. He hen came to the Jews and said:I swear by Allah, you have killed him. They said: We swear by Allah, we have not killed him. He then proceeded and came to his tribe and mentioned this to them. Then he, his brother Huwayyasah, who was older to him, and 'Abd al-Rahman b. Sahl came forward (to the Prophet). Muhayyasah began to speak. It was he who was at Khaibar. The Messenger of Allah (ﷺ) then said to him: Let the eldest (speak), let the eldest (speak), meaning age. So Huwayyasah spoke, and after him Muhayyasah spoke. The Messenger of Allah (ﷺ) then said: They should either pay the bloodwit for you friend or they should be prepared for war. So the Messenger of Allah (ﷺ) wrote to them about it. They wrote (in reply): We swear by Allah, we have not killed him. The Messenger of Allah (ﷺ) then said to Huwayyasah, Muhayyasah and 'Abd al-Rahman: Will you take an oath and thus have the claim to the blood of your friend ? They said: No. He (the Prophet) said: The Jews will then take an oath. They said: They are not Muslims. Then the Messenger of Allah (ﷺ) himself paid the bloodwit. The Messenger of Allah (ﷺ) then sent on one hundred she-camels and they were entered in their house. Sahl said: A red she-camel of them gave me a kick}}
\hadithdefcmd{abudawud}{4522}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَكَثِيرُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، أَخْبَرَنَا الْوَلِيدُ، عَنْ أَبِي عَمْرٍو، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَتَلَ بِالْقَسَامَةِ رَجُلاً مِنْ بَنِي نَصْرِ بْنِ مَالِكٍ بِبَحْرَةِ الرُّغَاءِ عَلَى شَطِّ لِيَّةِ الْبَحْرَةِ قَالَ الْقَاتِلُ وَالْمَقْتُولُ مِنْهُمْ ‏.‏ وَهَذَا لَفْظُ مَحْمُودٍ بِبَحْرَةٍ أَقَامَهُ مَحْمُودٌ وَحْدَهُ عَلَى شَطِّ لِيَّةِ الْبَحْرَةِ ‏.‏\hadithno{4522}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr b. Shu'aib: The Messenger of Allah (ﷺ) killed a man of Banu Nadr ibn Malik at Harrah ar-Righa' at the bank of Layyat al-Bahrah. The transmitter Mahmud (ibn Khalid) also mentioned the words along with the words "at Bahrah" "the slayer and the slain were from among them". Mahmud alone transmitted in this tradition the words "at the bank of Layyah}}
\hadithdefcmd{abudawud}{4523}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ الزَّعْفَرَانِيُّ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ الطَّائِيُّ، عَنْ بَشِيرِ بْنِ يَسَارٍ، زَعَمَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ سَهْلُ بْنُ أَبِي حَثْمَةَ أَخْبَرَهُ أَنَّ نَفَرًا مِنْ قَوْمِهِ انْطَلَقُوا إِلَى خَيْبَرَ فَتَفَرَّقُوا فِيهَا فَوَجَدُوا أَحَدَهُمْ قَتِيلاً فَقَالُوا لِلَّذِينَ وَجَدُوهُ عِنْدَهُمْ قَتَلْتُمْ صَاحِبَنَا فَقَالُوا مَا قَتَلْنَاهُ وَلاَ عَلِمْنَا قَاتِلاً ‏.‏ فَانْطَلَقْنَا إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم قَالَ فَقَالَ لَهُمْ ‏"‏ تَأْتُونِي بِالْبَيِّنَةِ عَلَى مَنْ قَتَلَ هَذَا ‏"‏ ‏.‏ قَالُوا مَا لَنَا بَيِّنَةٌ ‏.‏ قَالَ ‏"‏ فَيَحْلِفُونَ لَكُمْ ‏"‏ ‏.‏ قَالُوا لاَ نَرْضَى بِأَيْمَانِ الْيَهُودِ ‏.‏ فَكَرِهَ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنْ يُبْطِلَ دَمَهُ فَوَدَاهُ مِائَةً مِنْ إِبِلِ الصَّدَقَةِ ‏.‏\hadithno{4523}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6898) Sahih Muslim (1669)}\hadithtrans{Narrated Bashir b. Yasar:That a man of the Ansar called Sahl b. Abi Hathmah told him that some people of his tribe went to Khaibar and separated there. They found one of them slain. They said to those with whom they had found him: You have killed our friend. They replied: We did not kill him, nor do we know the slayer. We (the people of the slain) then went to the Prophet of Allah (ﷺ). He said to them: Bring proof against the one who has slain him. They replied: We have no proof. He said: Then they will take an oath for you. They said: We do not accept the oaths of the Jews. The Messenger of Allah (ﷺ) did not like no responsibility should be fixed for his blood. So he himself paid his bloodwit consisting of one hundred camels of sadaqah (i.e. camels sent to the Prophet as zakat)}}
\hadithdefcmd{abudawud}{4524}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيِّ بْنِ رَاشِدٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، حَدَّثَنَا عَبَايَةُ بْنُ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ أَصْبَحَ رَجُلٌ مِنَ الأَنْصَارِ مَقْتُولاً بِخَيْبَرَ فَانْطَلَقَ أَوْلِيَاؤُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرُوا ذَلِكَ لَهُ فَقَالَ ‏"‏ لَكُمْ شَاهِدَانِ يَشْهَدَانِ عَلَى قَتْلِ صَاحِبِكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ لَمْ يَكُنْ ثَمَّ أَحَدٌ مِنَ الْمُسْلِمِينَ وَإِنَّمَا هُمْ يَهُودُ وَقَدْ يَجْتَرِئُونَ عَلَى أَعْظَمَ مِنْ هَذَا ‏.‏ قَالَ ‏"‏ فَاخْتَارُوا مِنْهُمْ خَمْسِينَ فَاسْتَحْلِفُوهُمْ ‏"‏ ‏.‏ فَأَبَوْا فَوَدَاهُ النَّبِيُّ صلى الله عليه وسلم مِنْ عِنْدِهِ ‏.‏\hadithno{4524}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Rafi' ibn Khadij: A man of the Ansar was killed at Khaybar and his relatives went to the Prophet (ﷺ) and mentioned that to him. He asked: Have you two witnesses who can testify to the murderer of your friend? They replied: Messenger of Allah! there was not a single Muslim present, but only Jews who sometimes have the audacity to do even greater crimes than this. He said: Then choose fifty of them and demand that they take an oath; but they refused and the Prophet (ﷺ) paid the blood-wit himself}}
\hadithdefcmd{abudawud}{4525}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بُجَيْدٍ، قَالَ إِنَّ سَهْلاً وَاللَّهِ أَوْهَمَ الْحَدِيثَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى يَهُودَ ‏ "‏ أَنَّهُ قَدْ وُجِدَ بَيْنَ أَظْهُرِكُمْ قَتِيلٌ فَدُوهُ ‏"‏ ‏.‏ فَكَتَبُوا يَحْلِفُونَ بِاللَّهِ خَمْسِينَ يَمِينًا مَا قَتَلْنَاهُ وَلاَ عَلِمْنَا قَاتِلاً ‏.‏ قَالَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ مِائَةَ نَاقَةٍ ‏.‏\hadithno{4525}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abd al-Rahman b. Bujaid:I swear by Allah, Sahl had a misunderstanding about this tradition. The Messenger of Allah (ﷺ) wrote to the Jews: A slain man has been found amongnst you, so pay his bloodwit. They wrote (to him): Swearing by Allah fifty oaths, we neither killed him nor do we know his slayer. He said: Then the Messenger of Allah (ﷺ) himself paid his bloodwit which consisted of one hundred she-camels}}
\hadithdefcmd{abudawud}{4526}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَسُلَيْمَانَ بْنِ يَسَارٍ، عَنْ رِجَالٍ، مِنَ الأَنْصَارِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِلْيَهُودِ وَبَدَأَ بِهِمْ ‏"‏ يَحْلِفُ مِنْكُمْ خَمْسُونَ رَجُلاً ‏"‏ ‏.‏ فَأَبَوْا فَقَالَ لِلأَنْصَارِ ‏"‏ اسْتَحِقُّوا ‏"‏ ‏.‏ قَالُوا نَحْلِفُ عَلَى الْغَيْبِ يَا رَسُولَ اللَّهِ فَجَعَلَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم دِيَةً عَلَى يَهُودَ لأَنَّهُ وُجِدَ بَيْنَ أَظْهُرِهِمْ ‏.‏\hadithno{4526}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abu Salamah b. 'Abd al-Rahman and Sulaiman b. Yasar: On the authority of some men of the Ansar : The Prophet (ﷺ) said to the Jews and started with them: Fifty of you should take the oaths. But they refused (to take the oaths). He then said to the Ansar: Prove your claim. They said: Do we take the oaths without seeing, Messenger of Allah? The Messenger of Allah (ﷺ) then imposed the blood-wit on the Jews because he (the slain) was found among them}}
\hadithdefcmd{abudawud}{4527}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ جَارِيَةً، وُجِدَتْ، قَدْ رُضَّ رَأْسُهَا بَيْنَ حَجَرَيْنِ فَقِيلَ لَهَا مَنْ فَعَلَ بِكِ هَذَا أَفُلاَنٌ أَفُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ فَأَوْمَتْ بِرَأْسِهَا فَأُخِذَ الْيَهُودِيُّ فَاعْتَرَفَ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُرَضَّ رَأْسُهُ بِالْحِجَارَةِ ‏.‏\hadithno{4527}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2746) Sahih Muslim (1672)}\hadithtrans{Narrated Anas:A girl was found with her head crushed between two stones. She was asked: Who has done this to you ? Is it so and so ? Is it so and so, until a Jew was named, and she gave a sign with her head. The Jew was caught ad he admitted. So the Prophet (ﷺ) gave command that his head should be crushed with stones}}
\hadithdefcmd{abudawud}{4528}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ يَهُودِيًّا، قَتَلَ جَارِيَةً مِنَ الأَنْصَارِ عَلَى حُلِيٍّ لَهَا ثُمَّ أَلْقَاهَا فِي قَلِيبٍ وَرَضَخَ رَأْسَهَا بِالْحِجَارَةِ فَأُخِذَ فَأُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ بِهِ أَنْ يُرْجَمَ حَتَّى يَمُوتَ فَرُجِمَ حَتَّى مَاتَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جُرَيْجٍ عَنْ أَيُّوبَ نَحْوَهُ ‏.‏\hadithno{4528}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1672)}\hadithtrans{Narrated Anas: A Jew killed a girl of the Ansar for her ornaments. He then threw her in a well, and crushed her head with stones. He was then arrested and brought to the Prophet (ﷺ). He ordered regarding him that he should be stoned to death. He was then stoned till he died. Abu Dawud said: It has been transmitted by Ibn Juraij from Ayyub in a similar way}}
\hadithdefcmd{abudawud}{4529}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ جَدِّهِ، أَنَسٍ أَنَّ جَارِيَةً، كَانَ عَلَيْهَا أَوْضَاحٌ لَهَا فَرَضَخَ رَأْسَهَا يَهُودِيٌّ بِحَجَرٍ فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِهَا رَمَقٌ فَقَالَ لَهَا ‏"‏ مَنْ قَتَلَكِ فُلاَنٌ قَتَلَكِ ‏"‏ ‏.‏ فَقَالَتْ لاَ ‏.‏ بِرَأْسِهَا ‏.‏ قَالَ ‏"‏ مَنْ قَتَلَكِ فُلاَنٌ قَتَلَكِ ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ بِرَأْسِهَا ‏.‏ قَالَ ‏"‏ فُلاَنٌ قَتَلَكِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ بِرَأْسِهَا فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُتِلَ بَيْنَ حَجَرَيْنِ ‏.‏\hadithno{4529}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6877) Sahih Muslim (1672)}\hadithtrans{Narrated Anas:A girl was wearing silver ornaments. A Jew crushed her head with a stone. The Messenger of Allah (ﷺ) entered upon her when she had some breath. He said to her: Who has killed you ? Had so and so killed you ? She replied: No, making a sign with her head. He again asked: Who has killed you ? Has so and so killed you ? She replied: No, making a sign with her head. He again asked: Has so and so killed you ? She said: Yes, making sign with her head. The Messenger of Allah (ﷺ) commanded regarding him, and he was killed between two stones}}
\hadithdefcmd{abudawud}{4530}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ قَيْسِ بْنِ عَبَّادٍ، قَالَ انْطَلَقْتُ أَنَا وَالأَشْتَرُ، إِلَى عَلِيٍّ عَلَيْهِ السَّلاَمُ فَقُلْنَا هَلْ عَهِدَ إِلَيْكَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا لَمْ يَعْهَدْهُ إِلَى النَّاسِ عَامَّةً قَالَ لاَ إِلاَّ مَا فِي كِتَابِي هَذَا - قَالَ مُسَدَّدٌ قَالَ - فَأَخْرَجَ كِتَابًا - وَقَالَ أَحْمَدُ كِتَابًا مِنْ قِرَابِ سَيْفِهِ - فَإِذَا فِيهِ ‏ "‏ الْمُؤْمِنُونَ تَكَافَأُ دِمَاؤُهُمْ وَهُمْ يَدٌ عَلَى مَنْ سِوَاهُمْ وَيَسْعَى بِذِمَّتِهِمْ أَدْنَاهُمْ أَلاَ لاَ يُقْتَلُ مُؤْمِنٌ بِكَافِرٍ وَلاَ ذُو عَهْدٍ فِي عَهْدِهِ مَنْ أَحْدَثَ حَدَثًا فَعَلَى نَفْسِهِ وَمَنْ أَحْدَثَ حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ عَنِ ابْنِ أَبِي عَرُوبَةَ فَأَخْرَجَ كِتَابًا ‏.‏\hadithno{4530}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qays ibn Abbad : I and Ashtar went to Ali and said to him: Did the Messenger of Allah (ﷺ) give you any instruction about anything for which he did not give any instruction to the people in general? He said: No, except what is contained in this document of mine. Musaddad said: He then took out a document. Ahmad said: A document from the sheath of his sword. It contained: The lives of all Muslims are equal; they are one hand against others; the lowliest of them can guarantee their protection. Beware, a Muslim must not be killed for an infidel, nor must one who has been given a covenant be killed while his covenant holds. If anyone introduces an innovation, he will be responsible for it. If anyone introduces an innovation or gives shelter to a man who introduces an innovation (in religion), he is cursed by Allah, by His angels, and by all the people. Musaddad said: Ibn AbuUrubah's version has: He took out a document}}
\hadithdefcmd{abudawud}{4531}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَكَرَ نَحْوَ حَدِيثِ عَلِيٍّ زَادَ فِيهِ ‏ "‏ وَيُجِيرُ عَلَيْهِمْ أَقْصَاهُمْ وَيَرُدُّ مُشِدُّهُمْ عَلَى مُضْعِفِهِمْ وَمُتَسَرِّيهِمْ عَلَى قَاعِدِهِمْ ‏"‏ ‏.‏\hadithno{4531}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Messenger of Allah (ﷺ) said, mentioning the tradition similar to the one transmitted by Ali. This version adds: The most distant of them gives protection as from all, those who are strong among them send back (spoil) to those who are weak among them, and their expeditions sending it back to those who are at home}}
\hadithdefcmd{abudawud}{4532}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ الْحَوْطِيُّ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، قَالَ يَا رَسُولَ اللَّهِ الرَّجُلُ يَجِدُ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ سَعْدٌ بَلَى وَالَّذِي أَكْرَمَكَ بِالْحَقِّ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اسْمَعُوا إِلَى مَا يَقُولُ سَيِّدُكُمْ ‏"‏ ‏.‏ قَالَ عَبْدُ الْوَهَّابِ ‏"‏ إِلَى مَا يَقُولُ سَعْدٌ ‏"‏ ‏.‏\hadithno{4532}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1498)}\hadithtrans{Narrated Abu Hurairah:That Sa'd b. 'Ubadah said: Messenger of Allah! If a man finds a man with his wife, should he kill him ? The Messenger of Allah (ﷺ) said: No. Sa'd : Why not, by Him who has honoured you with truth ? The Prophet (ﷺ) said: Listen to what your chief is saying. The narrator 'Abd al-Wahhab said: (Listen) to what Sa'd is saying}}
\hadithdefcmd{abudawud}{4533}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرَأَيْتَ لَوْ وَجَدْتُ مَعَ امْرَأَتِي رَجُلاً أُمْهِلُهُ حَتَّى آتِيَ بِأَرْبَعَةِ شُهَدَاءَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{4533}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1498)}\hadithtrans{Narrated Abu Hurairah:That Sa'd b. 'Ubadah said to the Messenger of Allah (ﷺ) : What do you think if I find with my wife a man ; should I give him some time until I bring four witnesses ?" He said: "Yes}}
\hadithdefcmd{abudawud}{4534}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ أَبَا جَهْمِ بْنَ حُذَيْفَةَ مُصَدِّقًا فَلاَجَّهُ رَجُلٌ فِي صَدَقَتِهِ فَضَرَبَهُ أَبُو جَهْمٍ فَشَجَّهُ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا الْقَوَدَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَكُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ فَلَمْ يَرْضَوْا فَقَالَ ‏"‏ لَكُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ فَلَمْ يَرْضَوْا فَقَالَ ‏"‏ لَكُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ فَرَضُوا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي خَاطِبٌ الْعَشِيَّةَ عَلَى النَّاسِ وَمُخْبِرُهُمْ بِرِضَاكُمْ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ فَخَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ هَؤُلاَءِ اللَّيْثِيِّينَ أَتَوْنِي يُرِيدُونَ الْقَوَدَ فَعَرَضْتُ عَلَيْهِمْ كَذَا وَكَذَا فَرَضُوا أَرَضِيتُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ فَهَمَّ الْمُهَاجِرُونَ بِهِمْ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكُفُّوا عَنْهُمْ فَكَفُّوا ثُمَّ دَعَاهُمْ فَزَادَهُمْ فَقَالَ ‏"‏ أَرَضِيتُمْ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ إِنِّي خَاطِبٌ عَلَى النَّاسِ وَمُخْبِرُهُمْ بِرِضَاكُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَخَطَبَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَرَضِيتُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏\hadithno{4534}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) sent AbuJahm ibn Hudhayfah as a collector of zakat. A man quarrelled with him about his sadaqah (i.e. zakat), and AbuJahm struck him and wounded his head. His people came to the Prophet (ﷺ) and said: Revenge, Messenger of Allah! The Prophet (ﷺ) said: You may have so much and so much. But they did not agree. He again said: You may have so much and so much. But they did not agree. He again said: You may have so much and so much. So they agreed. The Prophet (ﷺ) said: I am going to address the people in the afternoon and tell them about your consent. They said: Yes. Addressing (the people), the Messenger of Allah (ﷺ) said: These people of faith came to me asking for revenge. I presented them with so much and so much and they agreed. Do you agree? They said: No. The immigrants (muhajirun) intended (to take revenge) on them. But the Messenger of Allah (ﷺ) commanded them to refrain and they refrained. He then called them and increased (the amount), and asked: Do you agree? They replied: Yes. He said: I am going to address the people and tell them about your consent. They said: Yes. The Prophet (ﷺ) addressed and said: Do you agree? They said: Yes}}
\hadithdefcmd{abudawud}{4535}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ جَارِيَةً، وُجِدَتْ، قَدْ رُضَّ رَأْسُهَا بَيْنَ حَجَرَيْنِ فَقِيلَ لَهَا مَنْ فَعَلَ بِكِ هَذَا أَفُلاَنٌ أَفُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ فَأَوْمَتْ بِرَأْسِهَا فَأُخِذَ الْيَهُودِيُّ فَاعْتَرَفَ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُرَضَّ رَأْسُهُ بِالْحِجَارَةِ ‏.‏\hadithno{4535}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2746) Sahih Muslim (1672)}\hadithtrans{Narrated Anas:A girl was found with her head crushed between two stoned. She was asked: Who did it with you ? Was it so and so ? Was it so and so ? Until the Jew was named. Thereupon she gave a sign with her head. The Jew was arrested and he admitted. So the Prophet (ﷺ) gave command that his head should be crushed with stones}}
\hadithdefcmd{abudawud}{4536}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرٍو، - يَعْنِي ابْنَ الْحَارِثِ - عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ عُبَيْدَةَ بْنِ مُسَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْسِمُ قَسْمًا أَقْبَلَ رَجُلٌ فَأَكَبَّ عَلَيْهِ فَطَعَنَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعُرْجُونٍ كَانَ مَعَهُ فَجُرِحَ بِوَجْهِهِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَالَ فَاسْتَقِدْ ‏"‏ ‏.‏ فَقَالَ بَلْ عَفَوْتُ يَا رَسُولَ اللَّهِ ‏.‏\hadithno{4536}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: When the Messenger of Allah (ﷺ) was distributing something, a man came towards him and bent down on him. The Messenger of Allah (ﷺ) struck him with a bough and his face was wounded. The Messenger of Allah (ﷺ) said to him: Come and take retaliation. He said: no, I have forgiven, Messenger of Allah}}
\hadithdefcmd{abudawud}{4537}{حَدَّثَنَا أَبُو صَالِحٍ، أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي فِرَاسٍ، قَالَ خَطَبَنَا عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه فَقَالَ إِنِّي لَمْ أَبْعَثْ عُمَّالِي لِيَضْرِبُوا أَبْشَارَكُمْ وَلاَ لِيَأْخُذُوا أَمْوَالَكُمْ فَمَنْ فُعِلَ بِهِ ذَلِكَ فَلْيَرْفَعْهُ إِلَىَّ أَقُصُّهُ مِنْهُ قَالَ عَمْرُو بْنُ الْعَاصِ لَوْ أَنَّ رَجُلاً أَدَّبَ بَعْضَ رَعِيَّتِهِ أَتَقُصُّهُ مِنْهُ قَالَ إِي وَالَّذِي نَفْسِي بِيَدِهِ أَقُصُّهُ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَصَّ مِنْ نَفْسِهِ ‏.‏\hadithno{4537}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Firas: 'Umar b. al-Khattab (ra) addressed us and said: I did not send my collectors (of zakat) so that they strike your bodies and that they take your property. If that is done with someone and he appeals to me, I shall take retaliation on him. Amr ibn al-'As said: If any man (i.e. governor) inflicts disciplinary punishment on his subjects, would you take retaliation on him too? He said: Yes, by Him in Whose hand my soul is, I shall take retaliation on him. I saw that the Messenger of Allah (ﷺ) has given retaliation on himself}}
\hadithdefcmd{abudawud}{4538}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، أَنَّهُ سَمِعَ حِصْنًا، أَنَّهُ سَمِعَ أَبَا سَلَمَةَ، يُخْبِرُ عَنْ عَائِشَةَ، رضى الله عنها عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ عَلَى الْمُقْتَتِلِينَ أَنْ يَنْحَجِزُوا الأَوَّلَ فَالأَوَّلَ وَإِنْ كَانَتِ امْرَأَةً ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ بَلَغَنِي أَنَّ عَفْوَ النِّسَاءِ فِي الْقَتْلِ جَائِزٌ إِذَا كَانَتْ إِحْدَى الأَوْلِيَاءِ وَبَلَغَنِي عَنْ أَبِي عُبَيْدٍ فِي قَوْلِهِ ‏"‏ يَنْحَجِزُوا ‏"‏ ‏.‏ يَكُفُّوا عَنِ الْقَوَدِ ‏.‏\hadithno{4538}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) Said: The disputants should refrain from taking retaliation. The one who is nearer should forgive first and then the one who is next to him, even if (the one who forgives) were a woman. Abu Dawud said: I have been informed that forgiving by women in the case of murder is permissible if a woman were one of the heirs (of the slain). I have been told on the authority of Abu 'Ubaid about the meaning of the word yanhajizu, that is, they should refrain from retaliation}}
\hadithdefcmd{abudawud}{4539}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، - وَهَذَا حَدِيثُهُ - عَنْ عَمْرٍو، عَنْ طَاوُسٍ، قَالَ مَنْ قُتِلَ ‏.‏ وَقَالَ ابْنُ عُبَيْدٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قُتِلَ فِي عِمِّيَّا فِي رَمْىٍ يَكُونُ بَيْنَهُمْ بِحِجَارَةٍ أَوْ ضَرْبٍ بِالسِّيَاطِ أَوْ ضَرْبٍ بِعَصًا فَهُوَ خَطَأٌ وَعَقْلُهُ عَقْلُ الْخَطَإِ وَمَنْ قُتِلَ عَمْدًا فَهُوَ قَوَدٌ ‏"‏ ‏.‏ وَقَالَ ابْنُ عُبَيْدٍ ‏"‏ قَوَدُ يَدٍ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا ‏"‏ وَمَنْ حَالَ دُونَهُ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَغَضَبُهُ لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏ ‏.‏ وَحَدِيثُ سُفْيَانَ أَتَمُّ ‏.‏\hadithno{4539}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Tawus, in his version said:If anyone is killed. Ibn 'Ubaid in his version said: The Messenger of Allah (ﷺ) said: If anyone is killed in error (blindly) when people are throwing stones, or by beating with whips, or striking with a stick, it is accidental and the compensation for accidental death is due. But if anyone is killed deliberately, retaliation is due. Ibn 'Ubaid in his version: Retaliation of the man is due. The agreed version then goes: If anyone comes in (between the two parties) to prevent it, Allah's curse and anger will rest on him, and neither supererogatory nor obligatory acts will be accepted from him. The version of the tradition of Sufyan is more perfect}}
\hadithdefcmd{abudawud}{4540}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي غَالِبٍ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، عَنْ سُلَيْمَانَ بْنِ كَثِيرٍ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَى حَدِيثِ سُفْيَانَ ‏.‏\hadithno{4540}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) as saying: He then mentioned the rest of the tradition to the same effect as mentioned by Sufyan}}
\hadithdefcmd{abudawud}{4541}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ مَنْ قُتِلَ خَطَأً فَدِيَتُهُ مِائَةٌ مِنَ الإِبِلِ ثَلاَثُونَ بِنْتَ مَخَاضٍ وَثَلاَثُونَ بِنْتَ لَبُونٍ وَثَلاَثُونَ حِقَّةً وَعَشْرَةٌ بَنِي لَبُونٍ ذَكَرٍ ‏.‏\hadithno{4541}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Messenger of Allah (ﷺ) gave judgment that if anyone is killed accidentally, his blood-wit should be one hundred camels: thirty she-camels which had entered their second year, thirty she-camels which had entered their third year, thirty she-camels which had entered their fourth year, and ten male camels which had entered their third year}}
\hadithdefcmd{abudawud}{4542}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُثْمَانَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَتْ قِيمَةُ الدِّيَةِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَمَانَمِائَةِ دِينَارٍ أَوْ ثَمَانِيَةَ آلاَفِ دِرْهَمٍ وَدِيَةُ أَهْلِ الْكِتَابِ يَوْمَئِذٍ النِّصْفُ مِنْ دِيَةِ الْمُسْلِمِينَ قَالَ فَكَانَ ذَلِكَ كَذَلِكَ حَتَّى اسْتُخْلِفَ عُمَرُ رَحِمَهُ اللَّهُ فَقَامَ خَطِيبًا فَقَالَ أَلاَ إِنَّ الإِبِلَ قَدْ غَلَتْ ‏.‏ قَالَ فَفَرَضَهَا عُمَرُ عَلَى أَهْلِ الذَّهَبِ أَلْفَ دِينَارٍ وَعَلَى أَهْلِ الْوَرِقِ اثْنَىْ عَشَرَ أَلْفًا وَعَلَى أَهْلِ الْبَقَرِ مِائَتَىْ بَقَرَةٍ وَعَلَى أَهْلِ الشَّاءِ أَلْفَىْ شَاةٍ وَعَلَى أَهْلِ الْحُلَلِ مِائَتَىْ حُلَّةٍ ‏.‏ قَالَ وَتَرَكَ دِيَةَ أَهْلِ الذِّمَّةِ لَمْ يَرْفَعْهَا فِيمَا رَفَعَ مِنَ الدِّيَةِ ‏.‏\hadithno{4542}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported that the value of the blood-money at the time of the Messenger of Allah (ﷺ) was eight hundred dinars or eight thousand dirhams, and the blood-money for the people of the Book was half of that for Muslims. He said: This applied till Umar (Allah be pleased with him) became caliph and he made a speech in which he said: Take note! Camels have become dear. So Umar fixed the value for those who possessed gold at one thousand dinars, for those who possessed silver at twelve thousand (dirhams), for those who possessed cattle at two hundred cows, for those who possessed sheep at two thousand sheep, and for those who possessed suits of clothing at two hundred suits. He left the blood-money for dhimmis (protected people) as it was, not raising it in proportion to the increase he made in the blood-wit}}
\hadithdefcmd{abudawud}{4543}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي الدِّيَةِ عَلَى أَهْلِ الإِبِلِ مِائَةً مِنَ الإِبِلِ وَعَلَى أَهْلِ الْبَقَرِ مِائَتَىْ بَقَرَةٍ وَعَلَى أَهْلِ الشَّاءِ أَلْفَىْ شَاةٍ وَعَلَى أَهْلِ الْحُلَلِ مِائَتَىْ حُلَّةٍ وَعَلَى أَهْلِ الْقَمْحِ شَيْئًا لَمْ يَحْفَظْهُ مُحَمَّدٌ ‏.‏\hadithno{4543}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ata' ibn AbuRabah: The Messenger of Allah (ﷺ) gave judgment that blood-wit for those who possessed camels should be one hundred camels, and for those who possessed cattle two hundred cows, and for those who possessed sheep one thousand sheep, and for those who possessed suits of clothing two hundred suits, and for those who possessed wheat something which the narrator Muhammad (ibn Ishaq) did not remember}}
\hadithdefcmd{abudawud}{4544}{قَالَ أَبُو دَاوُدَ قَرَأْتُ عَلَى سَعِيدِ بْنِ يَعْقُوبَ الطَّالْقَانِيِّ قَالَ حَدَّثَنَا أَبُو تُمَيْلَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، قَالَ ذَكَرَ عَطَاءٌ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مِثْلَ حَدِيثِ مُوسَى ‏.‏ قَالَ وَعَلَى أَهْلِ الطَّعَامِ شَيْئًا لاَ أَحْفَظُهُ ‏.‏\hadithno{4544}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Dawud said:I read out to Sa'id b. Ya'qub al-Taliqini who said: Abu Tumailah transmitted to us, saying: Muhammad b. Ishaq transmitted to us saying: 'Ata reported Jabir b. 'Abd Allah as saying: The Messenger of Allah (ﷺ) fixed; and he mentioned the tradition like that of Musa; he said: And those who possess corn food should pay something which I do not remember}}
\hadithdefcmd{abudawud}{4545}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الْحَجَّاجُ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنْ خِشْفِ بْنِ مَالِكٍ الطَّائِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي دِيَةِ الْخَطَإِ عِشْرُونَ حِقَّةً وَعِشْرُونَ جَذَعَةً وَعِشْرُونَ بِنْتَ مَخَاضٍ وَعِشْرُونَ بِنْتَ لَبُونٍ وَعِشْرُونَ بَنِي مَخَاضٍ ذُكُرٌ ‏"‏ ‏.‏ وَهُوَ قَوْلُ عَبْدِ اللَّهِ ‏.‏\hadithno{4545}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: The blood-wit for accidental killing should be twenty she-camels which had entered their fourth year, twenty she-camels which had entered their fifth year, twenty she-camels which had entered their second year, twenty she-camels which had entered their third year, and twenty male camels which had entered their second year. It does not beyond Ibn Mas'ud}}
\hadithdefcmd{abudawud}{4546}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، مِنْ بَنِي عَدِيٍّ قُتِلَ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم دِيَتَهُ اثْنَىْ عَشَرَ أَلْفًا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ عُيَيْنَةَ عَنْ عَمْرٍو عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ يَذْكُرِ ابْنَ عَبَّاسٍ ‏.‏\hadithno{4546}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: A man of Banu Adi was killed. The Prophet (ﷺ) fixed his blood-wit at the rate of twelve thousand (dirhams). Abu Dawud said: Ibn 'Uyainah transmitted it from 'Amr, from 'Ikrimah, from the Prophet (ﷺ), and he did not mention Ibn 'Abbas}}
\hadithdefcmd{abudawud}{4547}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ، عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ، عَنْ عُقْبَةَ بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ يَوْمَ الْفَتْحِ بِمَكَّةَ فَكَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ صَدَقَ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏ إِلَى هَا هُنَا حَفِظْتُهُ عَنْ مُسَدَّدٍ ثُمَّ اتَّفَقَا ‏"‏ أَلاَ إِنَّ كُلَّ مَأْثُرَةٍ كَانَتْ فِي الْجَاهِلِيَّةِ تُذْكَرُ وَتُدْعَى مِنْ دَمٍ أَوْ مَالٍ تَحْتَ قَدَمَىَّ إِلاَّ مَا كَانَ مِنْ سِقَايَةِ الْحَاجِّ وَسِدَانَةِ الْبَيْتِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ إِنَّ دِيَةَ الْخَطَإِ شِبْهِ الْعَمْدِ مَا كَانَ بِالسَّوْطِ وَالْعَصَا مِائَةٌ مِنَ الإِبِلِ مِنْهَا أَرْبَعُونَ فِي بُطُونِهَا أَوْلاَدُهَا ‏"‏ ‏.‏ وَحَدِيثُ مُسَدَّدٍ أَتَمُّ ‏.‏\hadithno{4547}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Amr: (Musaddad's version has): The Messenger of Allah (ﷺ) made a speech on the day of the conquest of Mecca, and said: Allah is Most Great, three times. He then said: There is no god but Allah alone: He fulfilled His promise, helped His servant, and alone defeated the companies. (The narrator said:) I have remembered from Musaddad up to this. Then the agreed version has: Take note! All the merits mentioned in pre-Islamic times, and the claim made for blood or property are under my feet, except the supply of water to the pilgrims and the custody of the Ka'bah. He then said: The blood-money for unintentional murder which appears intentional, such as is done with a whip and a stick, is one hundred camels, forty of which are pregnant. Musaddad's version is more accurate}}
\hadithdefcmd{abudawud}{4548}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، بِهَذَا الإِسْنَادِ نَحْوَ مَعْنَاهُ ‏.‏\hadithno{4548}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Khalid through the same chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4549}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ أَوْ فَتْحِ مَكَّةَ عَلَى دَرَجَةِ الْبَيْتِ أَوِ الْكَعْبَةِ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا رَوَاهُ ابْنُ عُيَيْنَةَ أَيْضًا عَنْ عَلِيِّ بْنِ زَيْدٍ عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَاهُ أَيُّوبُ السَّخْتِيَانِيُّ عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو مِثْلَ حَدِيثِ خَالِدٍ وَرَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ عَلِيِّ بْنِ زَيْدٍ عَنْ يَعْقُوبَ السَّدُوسِيِّ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَوْلُ زَيْدٍ وَأَبِي مُوسَى مِثْلُ حَدِيثِ النَّبِيِّ صلى الله عليه وسلم وَحَدِيثِ عُمَرَ رضى الله عنه ‏.‏\hadithno{4549}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar from the Prophet (ﷺ) to the same effect. This version has:The Messenger of Allah (ﷺ) addressed on the day of Conquest, or he said: On the conquest of Mecca on the ladder of the House or of the Ka'bah. Abu Dawud said: In a similar way of Ibn 'Uyainah also transmitted it from 'Ali b. Zaid, from al-Qasim b. Rab'iah, from Ibn 'Umar, from the Prophet (ﷺ) ; and Ayyub al-Sukhtiyani transmitted it from al-Qasim b. Rabi'ah from 'Abd Allah b. 'Amr like the tradition of Khalid. Hammad b. Salamah also transmitted it from 'Ali b. Zaid, from Ya'qub al-Sadusi, on the authority of 'Abd Allah b. 'Amr from the Prophet (ﷺ). The statements of Zaid and of Abu Musa are similar to the tradition of the Prophet (ﷺ) and to the tradition of 'Umar (Allah be pleased with him)}}
\hadithdefcmd{abudawud}{4550}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ قَضَى عُمَرُ فِي شِبْهِ الْعَمْدِ ثَلاَثِينَ حِقَّةً وَثَلاَثِينَ جَذَعَةً وَأَرْبَعِينَ خَلِفَةً مَا بَيْنَ ثَنِيَّةٍ إِلَى بَازِلِ عَامِهَا ‏.‏\hadithno{4550}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mujahid:'Umar gave judgement that bloodwit for quasi-intentional murder should be thirty she-camels in their fourth year, thirty she-camels in their fifth year, and forty pregnant she-camels in their sixth year up to the ninth}}
\hadithdefcmd{abudawud}{4551}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّهُ قَالَ فِي شِبْهِ الْعَمْدِ أَثَلاَثٌ ثَلاَثٌ وَثَلاَثُونَ حِقَّةً وَثَلاَثٌ وَثَلاَثُونَ جَذَعَةً وَأَرْبَعٌ وَثَلاَثُونَ ثَنِيَّةً إِلَى بَازِلِ عَامِهَا كُلُّهَا خَلِفَةٌ ‏.‏\hadithno{4551}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abd Allah (b. Mas'ud):The bloodwit for unintentional murder which resembles intentional is twenty-five she camels which entered their fourth year, twenty five she-camels which had entered their fifth year, twenty five she-camels which had entered their third year, and twenty five camels which had entered their second year}}
\hadithdefcmd{abudawud}{4552}{وَبِهِ عَنْ أَبِي إِسْحَاقَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، قَالَ عَبْدُ اللَّهِ فِي شِبْهِ الْعَمْدِ خَمْسٌ وَعِشْرُونَ حِقَّةً وَخَمْسٌ وَعِشْرُونَ جَذَعَةً وَخَمْسٌ وَعِشْرُونَ بَنَاتِ لَبُونٍ وَخَمْسٌ وَعِشْرُونَ بَنَاتِ مَخَاضٍ ‏.‏\hadithno{4552}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:The bloodwit for unintentional murder is in four parts: twenty five she-camels in their fourth year, twenty five she-camels in their fifth year, twenty five she-camels in their third year, and twenty twenty five she-camels in their second year}}
\hadithdefcmd{abudawud}{4553}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، قَالَ قَالَ عَلِيٌّ رضى الله عنه فِي الْخَطَإِ أَرْبَاعًا خَمْسٌ وَعِشْرُونَ حِقَّةً وَخَمْسٌ وَعِشْرُونَ جَذَعَةً وَخَمْسٌ وَعِشْرُونَ بَنَاتِ لَبُونٍ وَخَمْسٌ وَعِشْرُونَ بَنَاتِ مَخَاضٍ ‏.‏\hadithno{4553}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Uthman b. 'Affan and Zaid b. Thabit:The bloodwit for what resembled intentional murder should be forty pregnant she-camels in their fifth year, thirty she-camels in their fourth year, and thirty she-camels in their third year. The bloodwit for unintentional murder is thirty she-camels in their fourth year, thirty she-camels in their third year, and twenty she-camels in their second year}}
\hadithdefcmd{abudawud}{4554}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ رَبِّهِ، عَنْ أَبِي عِيَاضٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، وَزَيْدِ بْنِ ثَابِتٍ، فِي الْمُغَلَّظَةِ أَرْبَعُونَ جَذَعَةً خَلِفَةً وَثَلاَثُونَ حِقَّةً وَثَلاَثُونَ بَنَاتِ لَبُونٍ وَفِي الْخَطَإِ ثَلاَثُونَ حِقَّةً وَثَلاَثُونَ بَنَاتِ لَبُونٍ وَعِشْرُونَ بَنُو لَبُونٍ ذُكُورٍ وَعِشْرُونَ بَنَاتِ مَخَاضٍ ‏.‏\hadithno{4554}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaid b. Thabit:About the bloodwit for quasi-intentional murder..... He then mentioned a similar tradition as mentioned above}}
\hadithdefcmd{abudawud}{4555}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، فِي الدِّيَةِ الْمُغَلَّظَةِ فَذَكَرَ مِثْلَهُ سَوَاءً ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ أَبُو عُبَيْدٍ وَعَنْ غَيْرِ وَاحِدٍ إِذَا دَخَلَتِ النَّاقَةُ فِي السَّنَةِ الرَّابِعَةِ فَهُوَ حِقٌّ وَالأُنْثَى حِقَّةٌ لأَنَّهُ يَسْتَحِقُّ أَنْ يُحْمَلَ عَلَيْهِ وَيُرْكَبَ فَإِذَا دَخَلَ فِي الْخَامِسَةِ فَهُوَ جَذَعٌ وَجَذَعَةٌ فَإِذَا دَخَلَ فِي السَّادِسَةِ وَأَلْقَى ثَنِيَّتَهُ فَهُوَ ثَنِيٌّ وَثَنِيَّةٌ فَإِذَا دَخَلَ فِي السَّابِعَةِ فَهُوَ رَبَاعٌ وَرَبَاعِيَةٌ فَإِذَا دَخَلَ فِي الثَّامِنَةِ وَأَلْقَى السِّنَّ الَّذِي بَعْدَ الرَّبَاعِيَةِ فَهُوَ سَدِيسٌ وَسَدَسٌ فَإِذَا دَخَلَ فِي التَّاسِعَةِ وَفَطَرَ نَابُهُ وَطَلَعَ فَهُوَ بَازِلٌ فَإِذَا دَخَلَ فِي الْعَاشِرَةِ فَهُوَ مُخْلِفٌ ثُمَّ لَيْسَ لَهُ اسْمٌ وَلَكِنْ يُقَالُ بَازِلُ عَامٍ وَبَازِلُ عَامَيْنِ وَمُخْلِفُ عَامٍ وَمُخْلِفُ عَامَيْنِ إِلَى مَا زَادَ ‏.‏ وَقَالَ النَّضْرُ بْنُ شُمَيْلٍ بِنْتُ مَخَاضٍ لِسَنَةٍ وَبِنْتُ لَبُونٍ لِسَنَتَيْنِ وَحِقَّةٌ لِثَلاَثٍ وَجَذَعَةٌ لأَرْبَعٍ وَالثَّنِيُّ لِخَمْسٍ وَرَبَاعٌ لِسِتٍّ وَسَدِيسٌ لِسَبْعٍ وَبَازِلٌ لِثَمَانٍ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ أَبُو حَاتِمٍ وَالأَصْمَعِيُّ وَالْجَذُوعَةُ وَقْتٌ وَلَيْسَ بِسِنٍّ ‏.‏ قَالَ أَبُو حَاتِمٍ قَالَ بَعْضُهُمْ فَإِذَا أَلْقَى رَبَاعِيَتَهُ فَهُوَ رَبَاعٌ وَإِذَا أَلْقَى ثَنِيَّتَهُ فَهُوَ ثَنِيٌّ وَقَالَ أَبُو عُبَيْدٍ إِذَا أُلْقِحَتْ فَهِيَ خَلِفَةٌ فَلاَ تَزَالُ خَلِفَةً إِلَى عَشْرَةِ أَشْهُرٍ فَإِذَا بَلَغَتْ عَشْرَةَ أَشْهُرٍ فَهِيَ عُشَرَاءُ ‏.‏ قَالَ أَبُو حَاتِمٍ إِذَا أَلْقَى ثَنِيَّتَهُ فَهُوَ ثَنِيٌّ وَإِذَا أَلْقَى رَبَاعِيَتَهُ فَهُوَ رَبَاعٌ ‏.‏\hadithno{4555}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Dawud: Abu Dawud and others have said: When a she-camel enters fourth year, the female is called hiqqah, and the male is called hiqq, for it deserves that it should be loaded and ridden. When a camel enters its fifth year, the male is called Jadha' and the female is called Jadha'ah. When it enters its sixth year, and sheds its front teeth, it is called thani (male) and thaniyyah (female). When it enters its seventh year, it is called raba' and raba'iyyah. When it enters its ninth year and cuts its canine teeth, it is called bazil. When it enters its tenth year, it is called mukhlif. Then there is no name for it, but is called bazil'am and bazil'amain, and mukhlif'am and mukhlif'amain, upto any year it increases. Nad d. Shumail said: Bint makhad is a she-camel of one year, and bin labun is s she-camel of two years, hiqqah is a she-camel of three years, jadha'ah is a she-camel of four years, thani is a camel of five years, raba' is a camel of six years, sadis is a camel of seven years, and bazil is a camel of eight years. Abu Dawud said: Abu Hatim and al-Asma'i said: Al-Jadhu'ah is a time when no tooth is growing. Abu Hatim said: Some of them said: When it sheds its teeth between front and canine teeth, it is called raba' and when it sheds its front teeth, it is called thani. Abu 'Ubaid said: When it becomes pregnant, it is called khalifah, and it remains khalifah for ten months; when it reaches ten months, it is called 'ushara', Abu Hatim said: When it shed its front teeth, it is called thani and when it sheds its teeth between front and canine teeth it is called raba}}
\hadithdefcmd{abudawud}{4556}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدَةُ، - يَعْنِي ابْنَ سُلَيْمَانَ - حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ غَالِبٍ التَّمَّارِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ مَسْرُوقِ بْنِ أَوْسٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَصَابِعُ سَوَاءٌ عَشْرٌ عَشْرٌ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{4556}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuMusa: The Prophet (ﷺ) said: The fingers are equal: ten camels for each finger}}
\hadithdefcmd{abudawud}{4557}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ غَالِبٍ التَّمَّارِ، عَنْ مَسْرُوقِ بْنِ أَوْسٍ، عَنِ الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الأَصَابِعُ سَوَاءٌ ‏"‏ ‏.‏ قُلْتُ عَشْرٌ عَشْرٌ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ عَنْ غَالِبٍ قَالَ سَمِعْتُ مَسْرُوقَ بْنَ أَوْسٍ وَرَوَاهُ إِسْمَاعِيلُ قَالَ حَدَّثَنِي غَالِبٌ التَّمَّارُ بِإِسْنَادِ أَبِي الْوَلِيدِ وَرَوَاهُ حَنْظَلَةُ بْنُ أَبِي صَفِيَّةَ عَنْ غَالِبٍ بِإِسْنَادِ إِسْمَاعِيلَ ‏.‏\hadithno{4557}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Prophet (ﷺ) said: The fingers are equal. I asked: Ten camels for each? He replied: Yes. Abu Dawud said: Muhammad b. Ja'far transmitted it from Shu'bah, from Ghalib, saying: I heard Masruq b. Aws ; and Isma'il transmitted it, saying: Ghalib al-Tammar transmitted it to me through the chain of Abu al-Walid ; and Hanzlah b. Abi Safiyyah transmitted it from Ghalib through the chain of Isma'il}}
\hadithdefcmd{abudawud}{4558}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، ح وَحَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، كُلُّهُمْ عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَذِهِ وَهَذِهِ سَوَاءٌ ‏"‏ ‏.‏ قَالَ يَعْنِي الإِبْهَامَ وَالْخِنْصَرَ ‏.‏\hadithno{4558}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6895)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) as saying: This and that are equal, that is, the thumb and the little finger}}
\hadithdefcmd{abudawud}{4559}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَصَابِعُ سَوَاءٌ وَالأَسْنَانُ سَوَاءٌ الثَّنِيَّةُ وَالضِّرْسُ سَوَاءٌ هَذِهِ وَهَذِهِ سَوَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ النَّضْرُ بْنُ شُمَيْلٍ عَنْ شُعْبَةَ بِمَعْنَى عَبْدِ الصَّمَدِ ‏.‏ قَالَ أَبُو دَاوُدَ حَدَّثَنَاهُ الدَّارِمِيُّ عَنِ النَّضْرِ ‏.‏\hadithno{4559}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: The fingers are equal and the teeth are equal. The front tooth and the molar tooth are equal, this and that are equal. Abu Dawud said: Nadr b. Shumail transmitted it from Shu'bah to the same effect as mentioned by 'Abd al-Samad. Abu Dawud said: al-Darimi narrated it to me from al-Nadr}}
\hadithdefcmd{abudawud}{4560}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، أَخْبَرَنَا أَبُو حَمْزَةَ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَسْنَانُ سَوَاءٌ وَالأَصَابِعُ سَوَاءٌ ‏"‏ ‏.‏\hadithno{4560}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: The teeth are equal, and the fingers are equal}}
\hadithdefcmd{abudawud}{4561}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدِ بْنِ أَبَانَ، حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَصَابِعَ الْيَدَيْنِ وَالرِّجْلَيْنِ سَوَاءً ‏.‏\hadithno{4561}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) treated the fingers and toes as equal}}
\hadithdefcmd{abudawud}{4562}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي خُطْبَتِهِ وَهُوَ مُسْنِدٌ ظَهْرَهُ إِلَى الْكَعْبَةِ ‏ "‏ فِي الأَصَابِعِ عَشْرٌ عَشْرٌ ‏"‏ ‏.‏\hadithno{4562}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather said: The Prophet (ﷺ) said in his address while he was leaning against the Ka'bah: (The blood-wit) for each finger is ten camels}}
\hadithdefcmd{abudawud}{4563}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ أَبُو خَيْثَمَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونُ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الأَسْنَانِ خَمْسٌ خَمْسٌ ‏"‏ ‏.‏\hadithno{4563}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather said: The Prophet (ﷺ) said: For each tooth are ten camels}}
\hadithdefcmd{abudawud}{4564}{قَالَ أَبُو دَاوُدَ وَجَدْتُ فِي كِتَابِي عَنْ شَيْبَانَ، - وَلَمْ أَسْمَعْهُ مِنْهُ - فَحَدَّثْنَاهُ أَبُو بَكْرٍ، - صَاحِبٌ لَنَا ثِقَةٌ - قَالَ حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ رَاشِدٍ - عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ مُوسَى - عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَوِّمُ دِيَةَ الْخَطَإِ عَلَى أَهْلِ الْقُرَى أَرْبَعَمِائَةِ دِينَارٍ أَوْ عَدْلَهَا مِنَ الْوَرِقِ يُقَوِّمُهَا عَلَى أَثْمَانِ الإِبِلِ فَإِذَا غَلَتْ رَفَعَ فِي قِيمَتِهَا وَإِذَا هَاجَتْ رُخْصًا نَقَصَ مِنْ قِيمَتِهَا وَبَلَغَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا بَيْنَ أَرْبَعِمِائَةِ دِينَارٍ إِلَى ثَمَانِمِائَةِ دِينَارٍ أَوْ عَدْلَهَا مِنَ الْوَرِقِ ثَمَانِيَةَ آلاَفِ دِرْهَمٍ وَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَهْلِ الْبَقَرِ مِائَتَىْ بَقَرَةٍ وَمَنْ كَانَ دِيَةُ عَقْلِهِ فِي الشَّاءِ فَأَلْفَىْ شَاةٍ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْعَقْلَ مِيرَاثٌ بَيْنَ وَرَثَةِ الْقَتِيلِ عَلَى قَرَابَتِهِمْ فَمَا فَضَلَ فَلِلْعَصَبَةِ ‏"‏ ‏.‏ قَالَ وَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الأَنْفِ إِذَا جُدِعَ الدِّيَةَ كَامِلَةً وَإِنْ جُدِعَتْ ثَنْدُوَتُهُ فَنِصْفُ الْعَقْلِ خَمْسُونَ مِنَ الإِبِلِ أَوْ عَدْلُهَا مِنَ الذَّهَبِ أَوِ الْوَرِقِ أَوْ مِائَةُ بَقَرَةٍ أَوْ أَلْفُ شَاةٍ وَفِي الْيَدِ إِذَا قُطِعَتْ نِصْفُ الْعَقْلِ وَفِي الرِّجْلِ نِصْفُ الْعَقْلِ وَفِي الْمَأْمُومَةِ ثُلُثُ الْعَقْلِ ثَلاَثٌ وَثَلاَثُونَ مِنَ الإِبِلِ وَثُلْثٌ أَوْ قِيمَتُهَا مِنَ الذَّهَبِ أَوِ الْوَرِقِ أَوِ الْبَقَرِ أَوِ الشَّاءِ وَالْجَائِفَةُ مِثْلُ ذَلِكَ وَفِي الأَصَابِعِ فِي كُلِّ أُصْبُعٍ عَشْرٌ مِنَ الإِبِلِ وَفِي الأَسْنَانِ فِي كُلِّ سِنٍّ خَمْسٌ مِنَ الإِبِلِ وَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ عَقْلَ الْمَرْأَةِ بَيْنَ عَصَبَتِهَا مَنْ كَانُوا لاَ يَرِثُونَ مِنْهَا شَيْئًا إِلاَّ مَا فَضَلَ عَنْ وَرَثَتِهَا فَإِنْ قُتِلَتْ فَعَقْلُهَا بَيْنَ وَرَثَتِهَا وَهُمْ يَقْتُلُونَ قَاتِلَهُمْ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ لِلْقَاتِلِ شَىْءٌ وَإِنْ لَمْ يَكُنْ لَهُ وَارِثٌ فَوَارِثُهُ أَقْرَبُ النَّاسِ إِلَيْهِ وَلاَ يَرِثُ الْقَاتِلُ شَيْئًا ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ هَذَا كُلُّهُ حَدَّثَنِي بِهِ سُلَيْمَانُ بْنُ مُوسَى عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ مُحَمَّدُ بْنُ رَاشِدٍ مِنْ أَهْلِ دِمَشْقَ هَرَبَ إِلَى الْبَصْرَةِ مِنَ الْقَتْلِ ‏.‏\hadithno{4564}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Dawud: I found in my notebook from Shaiban and I did not hear from him ; Abu Bakr, a reliable friend of ours, said: Shaiban - Muhammad b. Rashid - Sulaiman b. Musad - 'Amr b. Suh'aib, On his father's authority, said that his grandfather said: The Messenger of Allah (ﷺ) would fix the blood-money for accidental killing at the rate of four hundred dinars or their equivalent in silver for townsmen, and he would fix it according to the price of camels. So when they were dear, he increased the amount to be paid, and when cheap prices prevailed he reduced the amount to be paid. In the time of the Messenger of Allah (ﷺ) they reached between four hundred and eight hundred dinars, their equivalent in silver being eight thousand dirhams. He said: The Messenger of Allah (ﷺ) gave judgment that those who possessed cattle should pay two hundred cows, and those who possessed sheep two thousand sheep. He said: The Messenger of Allah (ﷺ) said: The blood-money is to be treated as something to be inherited by the heirs of the one who has been killed, and the remainder should be divided among the agnates. He said: The Messenger of Allah (ﷺ) gave judgment that for cutting off a nose completely there was full blood-money, one hundred (camels) were to be paid. If the tip of the nose was cut off, half of the blood-money,i.e. fifty camels were to be paid, or their equivalent in gold or in silver, or a hundred cows, or one thousand sheep. For the hand, when it was cut of,f half of the blood-money was to be paid; for one foot of half, the blood-money was to be paid. For a wound in the head, a third of the blood-money was due, i.e. thirty-three camels and a third of the blood-money, or their equivalent in gold, silver, cows or sheep. For a head thrust which reaches the body, the same blood-money was to be paid. Ten camels were to be paid for every finger, and five camels for every tooth. The Messenger of Allah (ﷺ) gave judgment that the blood-money for a woman should be divided among her relatives on her father's side, who did not inherit anything from her except the residence of her heirs. If she was killed, her blood-money should be distributed among her heirs, and they would have the right of taking revenge on the murderer. The Messenger of Allah (ﷺ) said: There is nothing for the murderer; and if he (the victim) has no heir, his heir will be the one who is nearest to him among the people, but the murderer should not inherit anything. Muhammad said: All this has been transmitted to me by Sulayman ibn Musa on the authority of Amr ibn Shu'aib who, on his father's authority, said that his grandfather heard it from the Prophet (ﷺ). Abu Dawud said: Muhammad b. Rashid, an inhabitant of Damascus, fled from Basrah escaping murder}}
\hadithdefcmd{abudawud}{4565}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ بِلاَلٍ الْعَامِلِيُّ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ رَاشِدٍ - عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ مُوسَى - عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ عَقْلُ شِبْهِ الْعَمْدِ مُغَلَّظٌ مِثْلُ عَقْلِ الْعَمْدِ وَلاَ يُقْتَلُ صَاحِبُهُ ‏"‏ ‏.‏ قَالَ وَزَادَنَا خَلِيلٌ عَنِ ابْنِ رَاشِدٍ ‏"‏ وَذَلِكَ أَنْ يَنْزُوَ الشَّيْطَانُ بَيْنَ النَّاسِ فَتَكُونَ دِمَاءٌ فِي عِمِّيَّا فِي غَيْرِ ضَغِينَةٍ وَلاَ حَمْلِ سِلاَحٍ ‏"‏ ‏.‏\hadithno{4565}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Prophet (ﷺ) said: Blood-wit for what resembles intentional murder is to be made as severe as that for intentional murder, but the culprit is not to be killed. Khalid gave us some additional information on the authority of Ibn Rashid: That (unintentional murder which resembles intentional murder) means that Satan jumps among the people and then the blood is shed blindly without any malice and weapon}}
\hadithdefcmd{abudawud}{4566}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ أَنَّ خَالِدَ بْنَ الْحَارِثِ، حَدَّثَهُمْ قَالَ أَخْبَرَنَا حُسَيْنٌ، - يَعْنِي الْمُعَلِّمَ - عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ أَبَاهُ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْمَوَاضِحِ خَمْسٌ ‏"‏ ‏.‏\hadithno{4566}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Blood-wit for every wound which lays bare a bone is five camels}}
\hadithdefcmd{abudawud}{4567}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ السُّلَمِيُّ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُحَمَّدٍ - حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، حَدَّثَنِي الْعَلاَءُ بْنُ الْحَارِثِ، حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْعَيْنِ الْقَائِمَةِ السَّادَّةِ لِمَكَانِهَا بِثُلُثِ الدِّيَةِ ‏.‏\hadithno{4567}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather said: The Messenger of Allah (ﷺ) gave judgment that a third of the blood-wit should be paid for an eye fixed in its place}}
\hadithdefcmd{abudawud}{4568}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدِ بْنِ نَضْلَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ امْرَأَتَيْنِ، كَانَتَا تَحْتَ رَجُلٍ مِنْ هُذَيْلٍ فَضَرَبَتْ إِحْدَاهُمَا الأُخْرَى بِعَمُودٍ فَقَتَلَتْهَا وَجَنِينَهَا فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَحَدُ الرَّجُلَيْنِ كَيْفَ نَدِي مَنْ لاَ صَاحَ وَلاَ أَكَلَ وَلاَ شَرِبَ وَلاَ اسْتَهَلَّ ‏.‏ فَقَالَ ‏ "‏ أَسَجْعٌ كَسَجْعِ الأَعْرَابِ ‏"‏ ‏.‏ وَقَضَى فِيهِ بِغُرَّةٍ وَجَعَلَهُ عَلَى عَاقِلَةِ الْمَرْأَةِ ‏.‏\hadithno{4568}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1682)}\hadithtrans{Narrated Al-Mughirah b. Shu'bah:A man of Hudhail has two wives. One of them struck her fellow-wife with a tent-pole and killed her and her unborn child. They brought the dispute to the Prophet (ﷺ). One of two men said: How can we pay bloodwit for the one who did not make a noise, or ate, nor drank, nor raised his voice ? He (the Prophet) asked: Is it rhymed prose like that of bedouin? He gave judgement that a male or female slave of the best quality should be paid in compensation, and he fixed it to be paid by woman's relatives on her father's side}}
\hadithdefcmd{abudawud}{4569}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ وَزَادَ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم دِيَةَ الْمَقْتُولَةِ عَلَى عَصَبَةِ الْقَاتِلَةِ وَغُرَّةً لِمَا فِي بَطْنِهَا ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ الْحَكَمُ عَنْ مُجَاهِدٍ عَنِ الْمُغِيرَةِ ‏.‏\hadithno{4569}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1682)}\hadithtrans{The tradition mentioned above has also been transmitted by Mansur through a different chain of narrators and to the same effect. This version adds:The Prophet (ﷺ) fixed the bloodwit for the slain woman to be paid by the relatives of the woman who had slain her, on the father's side. Abu Dawud said: In a similar way it has been transmitted by al-Hakam from Mujahid from al-Mughirah}}
\hadithdefcmd{abudawud}{4570}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهَارُونُ بْنُ عَبَّادٍ الأَزْدِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ عُمَرَ، اسْتَشَارَ النَّاسَ فِي إِمْلاَصِ الْمَرْأَةِ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِيهَا بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏ فَقَالَ ائْتِنِي بِمَنْ يَشْهَدُ مَعَكَ ‏.‏ فَأَتَاهُ بِمُحَمَّدِ بْنِ مَسْلَمَةَ - زَادَ هَارُونُ - فَشَهِدَ لَهُ يَعْنِي ضَرَبَ الرَّجُلُ بَطْنَ امْرَأَتِهِ ‏.‏ قَالَ أَبُو دَاوُدَ بَلَغَنِي عَنْ أَبِي عُبَيْدٍ إِنَّمَا سُمِّيَ إِمْلاَصًا لأَنَّ الْمَرْأَةَ تَزْلِقُهُ قَبْلَ وَقْتِ الْوِلاَدَةِ وَكَذَلِكَ كُلُّ مَا زَلَقَ مِنَ الْيَدِ وَغَيْرِهِ فَقَدْ مَلِصَ ‏.‏\hadithno{4570}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1683)}\hadithtrans{Narrated Al-Miswar b. Makhramah: 'Umar consulted the people about the compensation of abortion of woman. Al-Mughirah b. Shu'bah said: I was present with the Messenger of Allah (ﷺ) when he gave judgement that a male or female slave should testify you. So he brought Muhammad b. Maslamah to him. Harun added: He then testified him. Imlas means a man striking the belly of his wife. Abu Dawud said: I have been informed that Abu 'Ubaid said: It (abortion) is called imlas because the woman causes it to slip before the time of delivery. Similarly, anything which slips from the hand or from some other thing is called malasa (slipped)}}
\hadithdefcmd{abudawud}{4571}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنَ هِشَامٍ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ، عَنْ عُمَرَ، بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَمَّادُ بْنُ زَيْدٍ وَحَمَّادُ بْنُ سَلَمَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ، قَالَ ‏.‏\hadithno{4571}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6905)}\hadithtrans{The tradition mentioned above has also been transmitted by 'Umar through a different chain of narrators to the same effect. Abu Dawud said:Hammad b. Zaid and Hammad b. Salamah transmitted it from Hisham b. 'Arubah on his father's authority who said that 'Umar said}}
\hadithdefcmd{abudawud}{4572}{حَدَّثَنَا مُحَمَّدُ بْنُ مَسْعُودٍ الْمِصِّيصِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ طَاوُسًا، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ، أَنَّهُ سَأَلَ عَنْ قَضِيَّةِ النَّبِيِّ، صلى الله عليه وسلم فِي ذَلِكَ فَقَامَ إِلَيْهِ حَمَلُ بْنُ مَالِكِ بْنِ النَّابِغَةِ فَقَالَ كُنْتُ بَيْنَ امْرَأَتَيْنِ فَضَرَبَتْ إِحْدَاهُمَا الأُخْرَى بِمِسْطَحٍ فَقَتَلَتْهَا وَجَنِينَهَا فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي جَنِينِهَا بِغُرَّةٍ وَأَنْ تُقْتَلَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ النَّضْرُ بْنُ شُمَيْلٍ الْمِسْطَحُ هُوَ الصَّوْبَجُ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ أَبُو عُبَيْدٍ الْمِسْطَحُ عُودٌ مِنْ أَعْوَادِ الْخِبَاءِ ‏.‏\hadithno{4572}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Ibn 'Abbas: 'Umar asked about the decision of the Prophet (ﷺ) about that (i.e. abortion). Haml b. Malik b. al-Nabhigah got up and said: I was between two women. One of them struck another with a rolling-pin killing both her and what was in her womb. So the Messenger of Allah (ﷺ) gave judgement that the bloodwit for the unborn child should be a male or a female slave of the best quality and the she should be killed. Abu Dawud said: Al-Nadr b. Shumail said: Mistah means a rolling-pin. Abu Dawud said: Abu 'Ubaid said: Mistah means a pole from the tent-poles}}
\hadithdefcmd{abudawud}{4573}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، قَالَ قَامَ عُمَرُ رضى الله عنه عَلَى الْمِنْبَرِ فَذَكَرَ مَعْنَاهُ لَمْ يَذْكُرْ وَأَنْ تُقْتَلَ ‏.‏ زَادَ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏ قَالَ فَقَالَ عُمَرُ اللَّهُ أَكْبَرُ لَوْ لَمْ أَسْمَعْ بِهَذَا لَقَضَيْنَا بِغَيْرِ هَذَا ‏.‏\hadithno{4573}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Tawus: Umar stood on the pulpit. He then mentioned the rest of the tradition to the same effect as mentioned before. He did not mention "that she should be killed". This version adds: "a male or a female slave". Umar then said: Allah is Most Great. Had I not heard it, we would have decided about it something else}}
\hadithdefcmd{abudawud}{4574}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ التَّمَّارُ، أَنَّ عَمْرَو بْنَ طَلْحَةَ، حَدَّثَهُمْ قَالَ حَدَّثَنَا أَسْبَاطٌ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قِصَّةِ حَمَلِ بْنِ مَالِكٍ قَالَ فَأَسْقَطَتْ غُلاَمًا قَدْ نَبَتَ شَعْرُهُ مَيِّتًا وَمَاتَتِ الْمَرْأَةُ فَقَضَى عَلَى الْعَاقِلَةِ الدِّيَةَ ‏.‏ فَقَالَ عَمُّهَا إِنَّهَا قَدْ أَسْقَطَتْ يَا نَبِيَّ اللَّهِ غُلاَمًا قَدْ نَبَتَ شَعْرُهُ ‏.‏ فَقَالَ أَبُو الْقَاتِلَةِ إِنَّهُ كَاذِبٌ إِنَّهُ وَاللَّهِ مَا اسْتَهَلَّ وَلاَ شَرِبَ وَلاَ أَكَلَ فَمِثْلُهُ يُطَلُّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَسَجْعَ الْجَاهِلِيَّةِ وَكَهَانَتَهَا أَدِّ فِي الصَّبِيِّ غُرَّةً ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ كَانَ اسْمُ إِحْدَاهُمَا مُلَيْكَةَ وَالأُخْرَى أُمَّ غُطَيْفٍ ‏.‏\hadithno{4574}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: About the story of Haml ibn Malik, Ibn Abbas said: She aborted a child who had grown hair and was dead, and the woman also died. He (the Prophet) gave judgment that the blood-wit was to be paid by the woman's relatives on the father's side. Her uncle said: Messenger of Allah! She has aborted a child who had grown hair. The father of the woman who had slain said: He is a liar: I swear by Allah, he did not raise his voice, or drink or eat. No compensation is to be paid for an offence like this. The Prophet (ﷺ) said: is it a rhymed prose of pre-Islamic Arabia and its soothsaying? Pay a male or female slave of the best quality in compensation for the child. Ibn 'Abbas said: The name of one of them was Mulaikah, and the name of the other was Umm Ghutaif}}
\hadithdefcmd{abudawud}{4575}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مُجَالِدٌ، قَالَ حَدَّثَنَا الشَّعْبِيُّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ امْرَأَتَيْنِ، مِنْ هُذَيْلٍ قَتَلَتْ إِحْدَاهُمَا الأُخْرَى وَلِكُلِّ وَاحِدَةٍ مِنْهُمَا زَوْجٌ وَوَلَدٌ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِيَةَ الْمَقْتُولَةِ عَلَى عَاقِلَةِ الْقَاتِلَةِ وَبَرَّأَ زَوْجَهَا وَوَلَدَهَا ‏.‏ قَالَ فَقَالَ عَاقِلَةُ الْمَقْتُولَةِ مِيرَاثُهَا لَنَا قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ مِيرَاثُهَا لِزَوْجِهَا وَوَلَدِهَا ‏"‏ ‏.‏\hadithno{4575}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: One of the two women of Hudhayl killed the other, Each of them had husband and sons. The Messenger of Allah (ﷺ) fixed the blood-wit for the slain woman to be paid by the woman's relatives on the father's side. He declared her husband and the child innocent. The relatives of the woman who killed said: We shall inherit from her. The Messenger of Allah (ﷺ) said: No, her sons and her husband should inherit from her}}
\hadithdefcmd{abudawud}{4576}{حَدَّثَنَا وَهْبُ بْنُ بَيَانٍ، وَابْنُ السَّرْحِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ اقْتَتَلَتِ امْرَأَتَانِ مِنْ هُذَيْلٍ فَرَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ فَقَتَلَتْهَا فَاخْتَصَمُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم دِيَةَ جَنِينِهَا غُرَّةٌ عَبْدٌ أَوْ وَلِيدَةٌ وَقَضَى بِدِيَةِ الْمَرْأَةِ عَلَى عَاقِلَتِهَا وَوَرَّثَهَا وَلَدَهَا وَمَنْ مَعَهُمْ فَقَالَ حَمَلُ بْنُ مَالِكِ بْنِ النَّابِغَةِ الْهُذَلِيُّ يَا رَسُولَ اللَّهِ كَيْفَ أَغْرَمُ دِيَةَ مَنْ لاَ شَرِبَ وَلاَ أَكَلَ وَلاَ نَطَقَ وَلاَ اسْتَهَلَّ فَمِثْلُ ذَلِكَ يُطَلُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏ ‏.‏ مِنْ أَجْلِ سَجْعِهِ الَّذِي سَجَعَ ‏.‏\hadithno{4576}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6910) Sahih Muslim (1681)}\hadithtrans{Narrated Abu Hurairah:Two women of Hudhail fought together and one of them threw a stone at the other and killed her. They brought their dispute to the Messenger of Allah (ﷺ) who gave judgement that a male or female slave of the best quality should be given as compensation for her unborn child, and he fixed it to be paid by the woman's relatives on the father's side. He made her sons and those who were with them her heirs. Hamal b. Malik b. al-Nabighah al-Hudhali said: Messenger of Allah ! how should I be fined for one who has not drunk, or eaten or spoken, or raised his voice? - adding that compensation is not to be paid for such (an offense). The Messenger of Allah (ﷺ) said: This man simply belong to the soothsayers on account of his rhymed prose which he has used}}
\hadithdefcmd{abudawud}{4577}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، فِي هَذِهِ الْقِصَّةِ قَالَ ثُمَّ إِنَّ الْمَرْأَةَ الَّتِي قَضَى عَلَيْهَا بِالْغُرَّةِ تُوُفِّيَتْ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَنَّ مِيرَاثَهَا لِبَنِيهَا وَأَنَّ الْعَقْلَ عَلَى عَصَبَتِهَا ‏.‏\hadithno{4577}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6740) Sahih Muslim (1681)}\hadithtrans{Narrated Abu Hurairah:About this story: Then the woman, against whom he decided that a male or female should be paid for her, died. The Messenger of Allah (ﷺ) then gave judgement that her sons will inherit from her, and the bloodwit should be paid by her relatives on the father's side}}
\hadithdefcmd{abudawud}{4578}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا يُوسُفُ بْنُ صُهَيْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، حَذَفَتِ امْرَأَةً فَأَسْقَطَتْ فَرُفِعَ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ فِي وَلَدِهَا خَمْسَمِائَةِ شَاةٍ وَنَهَى يَوْمَئِذٍ عَنِ الْحَذْفِ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا الْحَدِيثُ خَمْسَمِائَةِ شَاةٍ ‏.‏ وَالصَّوَابُ مِائَةُ شَاةٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَكَذَا قَالَ عَبَّاسٌ وَهُوَ وَهَمٌ ‏.‏\hadithno{4578}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Buraydah ibn al-Hasib: A woman threw a stone at another woman and she aborted. The dispute was brought to the Messenger of Allah (ﷺ). He gave judgment that five hundred sheep should be paid for her (unborn) child, and forbade throwing stones. Abu Dawud said: The version of this tradition goes in this way, i.e. five hundred sheep. What is correct is one hundred sheep. Abu Dawud said: 'Abbas transmitted this tradition this way, but it is misunderstanding}}
\hadithdefcmd{abudawud}{4579}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا عِيسَى، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنِينِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ أَوْ فَرَسٍ أَوْ بَغْلٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ حَمَّادُ بْنُ سَلَمَةَ وَخَالِدُ بْنُ عَبْدِ اللَّهِ عَنْ مُحَمَّدِ بْنِ عَمْرٍو لَمْ يَذْكُرَا أَوْ فَرَسٍ أَوْ بَغْلٍ ‏.‏\hadithno{4579}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) gave judgment that a male or a female slave, or a horse or a mule should be paid for a miscarriage. Abu Dawud said: Hammad b. Salamah and Khalid b. 'Abd Allah transmitted this tradition from Muhammad b. 'Amr, but they did not mention "or a horse or a mule}}
\hadithdefcmd{abudawud}{4580}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ الْعَوَقِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، وَجَابِرٍ، عَنِ الشَّعْبِيِّ، قَالَ الْغُرَّةُ خَمْسُمِائَةِ دِرْهَمٍ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ رَبِيعَةُ الْغُرَّةُ خَمْسُونَ دِينَارًا ‏.‏\hadithno{4580}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Sha'bi: The price of a male or a female slave is five hundred dirhams. Abu Dawud said: Rabi'ah said: The price of a male or a female slave is fifty dinars}}
\hadithdefcmd{abudawud}{4581}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَحَدَّثَنَا إِسْمَاعِيلُ، عَنْ هِشَامٍ، وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا حَجَّاجٌ الصَّوَّافُ، جَمِيعًا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي دِيَةِ الْمُكَاتَبِ يُقْتَلُ يُودَى مَا أَدَّى مِنْ مُكَاتَبَتِهِ دِيَةَ الْحُرِّ وَمَا بَقِيَ دِيَةَ الْمَمْلُوكِ ‏.‏\hadithno{4581}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) gave judgment about the slave who had made an agreement to purchase his freedom (mukatab) and he had been killed that blood-wit is paid for him at the rate paid for a free man so far as he has paid the purchase money, and at the rate paid for a slave as the remainder is concerned}}
\hadithdefcmd{abudawud}{4582}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَصَابَ الْمُكَاتَبُ حَدًّا أَوْ وَرِثَ مِيرَاثًا يَرِثُ عَلَى قَدْرِ مَا عَتَقَ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ وُهَيْبٌ عَنْ أَيُّوبَ عَنْ عِكْرِمَةَ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَرْسَلَهُ حَمَّادُ بْنُ زَيْدٍ وَإِسْمَاعِيلُ عَنْ أَيُّوبَ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَجَعَلَهُ إِسْمَاعِيلُ ابْنُ عُلَيَّةَ قَوْلَ عِكْرِمَةَ ‏.‏\hadithno{4582}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: When a mukatab (a slave who has made an agreement to purchase his freedom) gifts blood-money or an inheritance, he can inherit in accordance with the extent to which he has been emancipated. Abu Dawud said: Wuhaib transmitted it from Ayyub, from 'Ikrimah, on the authority of 'Ali, from the Prophet (ﷺ): and Hammad b. Zaid and Isma'il have transmitted it in a mursal form (i.e the link of the Companion being missing) from Ayyub, from 'Ikrimah, from the Prophet (ﷺ). Isma'il b. 'Ulayyah has treated it as a statement of 'Ikrimah}}
\hadithdefcmd{abudawud}{4583}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دِيَةُ الْمُعَاهِدِ نِصْفُ دِيَةِ الْحُرِّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ وَعَبْدُ الرَّحْمَنِ بْنُ الْحَارِثِ عَنْ عَمْرِو بْنِ شُعَيْبٍ مِثْلَهُ ‏.‏\hadithno{4583}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Messenger of Allah (ﷺ) said: The blood-wit for a man who makes a covenant is half of the blood-wit for a free man. Abu Dawud said: It has been transmitted by Usamah b. Zaid al-Laithi and 'Abd al-Rahman b. al-Harith on the authority of 'Amr b. Suh'aib in similar manner}}
\hadithdefcmd{abudawud}{4584}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ قَاتَلَ أَجِيرٌ لِي رَجُلاً فَعَضَّ يَدَهُ فَانْتَزَعَهَا فَنَدَرَتْ ثَنِيَّتُهُ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَهْدَرَهَا وَقَالَ ‏ "‏ أَتُرِيدُ أَنْ يَضَعَ يَدَهُ فِي فِيكَ تَقْضَمُهَا كَالْفَحْلِ ‏"‏ ‏.‏ قَالَ وَأَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ عَنْ جَدِّهِ أَنَّ أَبَا بَكْرٍ رَضِيَ اللَّهُ عَنْهُ أَهْدَرَهَا وَقَالَ بَعُدَتْ سِنُّهُ ‏.‏\hadithno{4584}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6893) Sahih Muslim (1674)}\hadithtrans{Narrated Safwan b. Ya'la:On this father's authority, said: A servant of mine fought with a man and bit his hand and he drew away his hand. (One of) his front teeth fell out. So he came to the Prophet (ﷺ) who imposed no retaliation for his tooth, saying: Do you intend that he leaves his hand in your mouth so that you crunch it like a male camel ? He said: Ibn Abi Mulaikah told me on the authority of his grandfather that Abu Bakr (ra) imposed no retaliation on him for it, saying: May his tooth go away}}
\hadithdefcmd{abudawud}{4585}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، أَخْبَرَنَا هُشَيْمٌ، حَدَّثَنَا حَجَّاجٌ، وَعَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، بِهَذَا زَادَ ثُمَّ قَالَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم لِلْعَاضِّ ‏ "‏ إِنْ شِئْتَ أَنْ تُمَكِّنَهُ مِنْ يَدِكَ فَيَعَضَّهَا ثُمَّ تَنْزِعَهَا مِنْ فِيهِ ‏"‏ ‏.‏ وَأَبْطَلَ دِيَةَ أَسْنَانِهِ ‏.‏\hadithno{4585}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ya'la b. Umayyah through a different chain of narrators. This version has:The Prophet (ﷺ) said to the man bit him: If you wish that you give him control over your hand and he bites it, and then you drive it away from his mouth (you may do it). He imposed no retaliation for his teeth}}
\hadithdefcmd{abudawud}{4586}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، أَنَّ الْوَلِيدَ بْنَ مُسْلِمٍ، أَخْبَرَهُمْ عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَطَبَّبَ وَلاَ يُعْلَمُ مِنْهُ طِبٌّ فَهُوَ ضَامِنٌ ‏"‏ ‏.‏ قَالَ نَصْرٌ قَالَ حَدَّثَنِي ابْنُ جُرَيْجٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لَمْ يَرْوِهِ إِلاَّ الْوَلِيدُ لاَ نَدْرِي هُوَ صَحِيحٌ أَمْ لاَ ‏.‏\hadithno{4586}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather reported the Messenger of Allah (ﷺ) said: Anyone who practises medicine when he is not known as a practitioner will be held responsible. Abu Dawud said: This has been transmitted by al-Walid alone. We do not know whether it is sound or not}}
\hadithdefcmd{abudawud}{4587}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، حَدَّثَنِي بَعْضُ الْوَفْدِ الَّذِينَ، قَدِمُوا عَلَى أَبِي قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا طَبِيبٍ تَطَبَّبَ عَلَى قَوْمٍ لاَ يُعْرَفُ لَهُ تَطَبُّبٌ قَبْلَ ذَلِكَ فَأَعْنَتَ فَهُوَ ضَامِنٌ ‏"‏ ‏.‏ قَالَ عَبْدُ الْعَزِيزِ أَمَا إِنَّهُ لَيْسَ بِالنَّعْتِ إِنَّمَا هُوَ قَطْعُ الْعُرُوقِ وَالْبَطُّ وَالْكَىُّ ‏.‏\hadithno{4587}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdulAziz ibn Umar ibn AbdulAziz: Some people of the deputation which came to my father reported the Messenger of Allah (ﷺ) as saying: Any physician who practises medicine when he was not known as a practitioner before that and he harms (the patients) he will be held responsible. AbdulAziz said: Here physician does not refer to a man by qualification. it means opening a vein, incision and cauterisation}}
\hadithdefcmd{abudawud}{4588}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ، عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ، عَنْ عُقْبَةَ بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم - قَالَ مُسَدَّدٌ - خَطَبَ يَوْمَ الْفَتْحِ - ثُمَّ اتَّفَقَا - فَقَالَ ‏"‏ أَلاَ إِنَّ كُلَّ مَأْثُرَةٍ كَانَتْ فِي الْجَاهِلِيَّةِ مِنْ دَمٍ أَوْ مَالٍ تُذْكَرُ وَتُدْعَى تَحْتَ قَدَمَىَّ إِلاَّ مَا كَانَ مِنْ سِقَايَةِ الْحَاجِّ وَسِدَانَةِ الْبَيْتِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ إِنَّ دِيَةَ الْخَطَإِ شِبْهِ الْعَمْدِ مَا كَانَ بِالسَّوْطِ وَالْعَصَا مِائَةٌ مِنَ الإِبِلِ مِنْهَا أَرْبَعُونَ فِي بُطُونِهَا أَوْلاَدُهَا ‏"‏ ‏.‏\hadithno{4588}\hadithgrade{Al-Albani: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Musaddad's version has: He addressed on the day of Conquest. The agreed version then goes: Beware! Every object of pride of pre-Islamic times, whether it is blood-vengeance or property, mentioned or claimed, has been put under my feet except supply of water to the pilgrims and custody of the House (the Ka'bah). He then said: Beware! The blood-wit for unintentional murder, such as is done with a whip and stick, is one hundred camels, forty of which are pregnant}}
\hadithdefcmd{abudawud}{4589}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، بِهَذَا الإِسْنَادِ نَحْوَ مَعْنَاهُ ‏.‏\hadithno{4589}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Khalid with a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4590}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ غُلاَمًا، لأُنَاسٍ فُقَرَاءَ قَطَعَ أُذُنَ غُلاَمٍ لأُنَاسٍ أَغْنِيَاءَ فَأَتَى أَهْلُهُ النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا أُنَاسٌ فُقَرَاءُ ‏.‏ فَلَمْ يَجْعَلْ عَلَيْهِ شَيْئًا ‏.‏\hadithno{4590}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: A servant of some poor people cut off the ear of the servant of some rich people. His people came to the Prophet (ﷺ) and said: Messenger of Allah! we are poor people. So he imposed no compensation on them}}
\hadithdefcmd{abudawud}{4591}{قَالَ أَبُو دَاوُدَ حُدِّثْتُ عَنْ سَعِيدِ بْنِ سُلَيْمَانَ، عَنْ سُلَيْمَانَ بْنِ كَثِيرٍ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ فِي عِمَّيَّا أَوْ رَمْيًا يَكُونُ بَيْنَهُمْ بِحَجَرٍ أَوْ بِسَوْطٍ فَعَقْلُهُ عَقْلُ خَطَإٍ وَمَنْ قُتِلَ عَمْدًا فَقَوْدُ يَدَيْهِ فَمَنْ حَالَ بَيْنَهُ وَبَيْنَهُ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{4591}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone is killed blindly or, when people are throwing stones, by a stone or a whip, his blood-wit is the blood-wit for an accidental murder. But if anyone is killed intentionally, retaliation is due. If anyone tries to prevent it, the curse of Allah, of angels, and of all the people will rest on him}}
\hadithdefcmd{abudawud}{4592}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ، حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرِّجْلُ جُبَارٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الدَّابَّةُ تَضْرِبُ بِرِجْلِهَا وَهُوَ رَاكِبٌ ‏.‏\hadithno{4592}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: No recompense is to be demanded if one is kicked by an animal. Abu Dawud said: An animal kicks someone with its leg while one is riding on it}}
\hadithdefcmd{abudawud}{4593}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ سَمِعَا أَبَا هُرَيْرَةَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَالْبِئْرُ جُبَارٌ وَفِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْعَجْمَاءُ الْمُنْفَلِتَةُ الَّتِي لاَ يَكُونُ مَعَهَا أَحَدٌ وَتَكُونُ بِالنَّهَارِ وَلاَ تَكُونُ بِاللَّيْلِ ‏.‏\hadithno{4593}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1499) Sahih Muslim (1710)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: No retaliation is payable for a wound caused by a dumb animal, for a mine, and for a well. On the treasure found buried in the land there is a fifth. Abu Dawud said: A dumb animal means an animal which is free and has not tether, and there is no one (as a watchman) with it. It causes harm by day and not by night}}
\hadithdefcmd{abudawud}{4594}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، ح وَحَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا عَبْدُ الْمَلِكِ الصَّنْعَانِيُّ، كِلاَهُمَا عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ النَّارُ جُبَارٌ ‏"‏ ‏.‏\hadithno{4594}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: No recompense may be demanded if the fire spreads}}
\hadithdefcmd{abudawud}{4595}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَسَرَتِ الرُّبَيِّعُ أُخْتُ أَنَسِ بْنِ النَّضْرِ ثَنِيَّةَ امْرَأَةٍ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَضَى بِكِتَابِ اللَّهِ الْقِصَاصَ فَقَالَ أَنَسُ بْنُ النَّضْرِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ثَنِيَّتُهَا الْيَوْمَ ‏.‏ قَالَ ‏"‏ يَا أَنَسُ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏ ‏.‏ فَرَضُوا بِأَرْشٍ أَخَذُوهُ فَعَجِبَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ قِيلَ لَهُ كَيْفَ يُقْتَصُّ مِنَ السِّنِّ قَالَ تُبْرَدُ ‏.‏\hadithno{4595}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2703)}\hadithtrans{Narrated Anas bin Malik:Al-Rubayyi', sister of Anas b. al-Nadr, broke (one of) the front teeth of a woman. They came to the Prophet (ﷺ). He made a decision in accordance with the Book of Allah that retaliation should be taken. Anas b. al-Nadr said: I swear by Him who has sent you the truth, her front tooth will not be broken today. He replied: Anas ! Allah's decree is retaliation. But the people were agreeable to accepting a fine, so the Prophet (ﷺ) said: Among Allah's servants there are those who, if they adjured Allah, He (Allah) would consent to it. Abu Dawud said: I heard Ahmad b. Hanbal say: He was asked : How retaliation of a tooth is taken ? He said: It is broken with a file}}
